@@ -75,6 +75,17 @@ Aa::getModificationList() const
   return m_listMod;
 }
 
+double
+Aa::getTotalModificationMass() const
+{
+  double mass = 0;
+  for(auto &&mod : m_listMod)
+    {
+      mass += mod->getMass();
+    }
+  return mass;
+}
+
 pappso_double
 Aa::getMass() const
 {
@@ -132,6 +143,35 @@ Aa::toString() const
   return seq;
 }
 
+const QString
+Aa::toProForma() const
+{
+  QString seq = "";
+  seq += this->getLetter();
+
+  std::vector<AaModificationP> copy_mod_list = m_listMod;
+  std::sort(copy_mod_list.begin(),
+            copy_mod_list.end(),
+            [](const AaModificationP &a, const AaModificationP &b) {
+              return a->getAccession() < b->getAccession();
+            });
+  auto it(copy_mod_list.begin());
+  if(it != copy_mod_list.end())
+    {
+      QStringList modification_str_list;
+      while(it != copy_mod_list.end())
+        {
+          if(!(*it)->isInternal())
+            {
+              modification_str_list << (*it)->toProForma();
+            }
+          it++;
+        }
+      if(modification_str_list.size() > 0)
+        seq += QString("[%1]").arg(modification_str_list.join("]["));
+    }
+  return seq;
+}
 
 void
 Aa::removeAaModification(AaModificationP mod)
@@ -228,19 +268,40 @@ Aa::getInternalCterModification() const
 void
 Aa::removeInternalNterModification()
 {
-  std::remove_if(
-    m_listMod.begin(), m_listMod.end(), [](AaModificationP const &mod) {
-      return mod->getAccession().startsWith("internal:Nter_");
-    });
+  m_listMod.erase(std::remove_if(m_listMod.begin(),
+                                 m_listMod.end(),
+                                 [](AaModificationP const &mod) {
+                                   return mod->getAccession().startsWith(
+                                     "internal:Nter_");
+                                 }),
+                  m_listMod.end());
+  sort(m_listMod.begin(), m_listMod.end());
 }
 
 void
 Aa::removeInternalCterModification()
 {
-  std::remove_if(
-    m_listMod.begin(), m_listMod.end(), [](AaModificationP const &mod) {
-      return mod->getAccession().startsWith("internal:Cter_");
-    });
+  m_listMod.erase(std::remove_if(m_listMod.begin(),
+                                 m_listMod.end(),
+                                 [](AaModificationP const &mod) {
+                                   return mod->getAccession().startsWith(
+                                     "internal:Cter_");
+                                 }),
+                  m_listMod.end());
+  sort(m_listMod.begin(), m_listMod.end());
+}
+
+void
+Aa::removeAllButInternalModification()
+{
+
+  m_listMod.erase(std::remove_if(m_listMod.begin(),
+                                 m_listMod.end(),
+                                 [](AaModificationP const &mod) {
+                                   return !mod->getAccession().startsWith(
+                                     "internal:");
+                                 }),
+                  m_listMod.end());
 }
 
 bool
