@@ -95,12 +95,53 @@ AaModification::getAccession() const
   return m_accession;
 }
 
+
+const QString
+AaModification::toProForma() const
+{
+  QString str_return;
+  // qDebug();
+  if(m_accession.startsWith("MOD:"))
+    return m_accession;
+
+  if(m_accession.startsWith("internal:"))
+    return str_return;
+
+  if(m_accession.startsWith("MUTATION:"))
+    {
+      // MUTATION:%1=>%2
+      QStringList aa_list = m_accession.mid(9).split("=>");
+      // first, find removal accession
+      return QString("%1][%2")
+        .arg(getInstanceRemovalAccessionByAaLetter(aa_list[0].at(0))
+               ->getAccession())
+        .arg(getInstanceInsertionAccessionByAaLetter(aa_list[1].at(0))
+               ->getAccession());
+    }
+
+  if(m_mass > 0)
+    {
+      return QString("+%1").arg(QString::number(m_mass, 'f', 4));
+    }
+  else
+    {
+      return QString("%1").arg(QString::number(m_mass, 'f', 4));
+    }
+  return str_return;
+}
+
 const QString &
 AaModification::getName() const
 {
   return m_name;
 }
 
+const QString &
+AaModification::getXrefOrigin() const
+{
+  return m_origin;
+}
+
 AaModification::MapAccessionModifications
   AaModification::m_mapAccessionModifications = [] {
     MapAccessionModifications ret;
@@ -118,6 +159,21 @@ AaModification::createInstance(const OboPsiModTerm &term)
   new_mod->setDiffFormula(term.m_diffFormula);
   new_mod->setXrefOrigin(term.m_origin);
   new_mod->m_name = term.m_name;
+
+  qDebug() << "is_a " << term.m_isA.join(" ");
+  if(term.isA("MOD:01441"))
+    {
+      qDebug() << "term.isA(MOD:01441)";
+      if(term.m_origin.isEmpty())
+        {
+          throw ExceptionNotFound(
+            QObject::tr("origin not found for term : [%1]")
+              .arg(term.m_accession));
+        }
+
+      new_mod->setDiffFormula(term.m_formula);
+      // new_mod->m_mass = AaBase::getAaMass(term.m_origin[0].toLatin1());
+    }
   qDebug() << new_mod->m_mass;
   return new_mod;
 }
@@ -441,6 +497,230 @@ AaModification::getInstance(const QString &accession)
     }
 }
 
+AaModificationP
+AaModification::getInstanceRemovalAccessionByAaLetter(const QChar &amino_acid)
+{
+  switch(amino_acid.toLatin1())
+    {
+      //    AminoAcidChar::alanine
+      case 'A':
+        return getInstance("MOD:01631");
+        break;
+        // AminoAcidChar::arginine,
+      case 'R':
+        return getInstance("MOD:01632");
+        break;
+        // AminoAcidChar::cysteine,
+      case 'C':
+        return getInstance("MOD:01635");
+        break;
+        // AminoAcidChar::aspartic_acid,
+      case 'D':
+        return getInstance("MOD:01634");
+        break;
+        // AminoAcidChar::glutamic_acid,
+      case 'E':
+        return getInstance("MOD:01636");
+        break;
+
+        // AminoAcidChar::phenylalanine,
+      case 'F':
+        return getInstance("MOD:01644");
+        break;
+        // AminoAcidChar::glycine,
+      case 'G':
+        return getInstance("MOD:01638");
+        break;
+        // AminoAcidChar::histidine,
+      case 'H':
+        return getInstance("MOD:01639");
+        break;
+
+        // AminoAcidChar::isoleucine,
+      case 'I':
+        return getInstance("MOD:01640");
+        break;
+
+        // AminoAcidChar::lysine,
+      case 'K':
+        return getInstance("MOD:01642");
+        break;
+        // AminoAcidChar::leucine,
+      case 'L':
+        return getInstance("MOD:01641");
+        break;
+
+        // AminoAcidChar::methionine,
+      case 'M':
+        return getInstance("MOD:01643");
+        break;
+
+        // AminoAcidChar::asparagine,
+      case 'N':
+        return getInstance("MOD:01633");
+        break;
+
+        // AminoAcidChar::proline,
+      case 'P':
+        return getInstance("MOD:01645");
+        break;
+
+        // AminoAcidChar::glutamine,
+      case 'Q':
+        return getInstance("MOD:01637");
+        break;
+        // AminoAcidChar::serine,
+      case 'S':
+        return getInstance("MOD:01646");
+        break;
+
+        // AminoAcidChar::threonine,
+      case 'T':
+        return getInstance("MOD:01647");
+        break;
+
+
+        // AminoAcidChar::valine,
+      case 'V':
+        return getInstance("MOD:01650");
+        break;
+
+        // AminoAcidChar::tryptophan,
+      case 'W':
+        return getInstance("MOD:01648");
+        break;
+
+        // AminoAcidChar::tyrosine,
+      case 'Y':
+        return getInstance("MOD:01649");
+        break;
+
+      default:
+        throw ExceptionNotFound(
+          QObject::tr("ERROR getting removal accession instance of amino acid: "
+                      "%1 NOT FOUND")
+            .arg(amino_acid));
+    }
+}
+
+AaModificationP
+AaModification::getInstanceInsertionAccessionByAaLetter(const QChar &amino_acid)
+{
+  pappso::AaModificationP aa_insert = nullptr;
+  switch(amino_acid.toLatin1())
+    {
+      //    AminoAcidChar::alanine
+      case 'A':
+        aa_insert = getInstance("MOD:00010");
+        break;
+
+        // AminoAcidChar::arginine,
+      case 'R':
+        aa_insert = getInstance("MOD:00011");
+        break;
+
+        // AminoAcidChar::cysteine,
+      case 'C':
+        aa_insert = getInstance("MOD:00014");
+        break;
+
+        // AminoAcidChar::aspartic_acid,
+      case 'D':
+        aa_insert = getInstance("MOD:00013");
+        break;
+
+        // AminoAcidChar::glutamic_acid,
+      case 'E':
+        aa_insert = getInstance("MOD:00015");
+        break;
+
+        // AminoAcidChar::phenylalanine,
+      case 'F':
+        aa_insert = getInstance("MOD:00023");
+        break;
+
+        // AminoAcidChar::glycine,
+      case 'G':
+        aa_insert = getInstance("MOD:00017");
+        break;
+
+        // AminoAcidChar::histidine,
+      case 'H':
+        aa_insert = getInstance("MOD:00018");
+        break;
+
+        // AminoAcidChar::isoleucine,
+      case 'I':
+        aa_insert = getInstance("MOD:00019");
+        break;
+
+        // AminoAcidChar::lysine,
+      case 'K':
+        aa_insert = getInstance("MOD:00021");
+        break;
+        // AminoAcidChar::leucine,
+      case 'L':
+        aa_insert = getInstance("MOD:00020");
+        break;
+
+        // AminoAcidChar::methionine,
+      case 'M':
+        aa_insert = getInstance("MOD:00022");
+        break;
+
+        // AminoAcidChar::asparagine,
+      case 'N':
+        aa_insert = getInstance("MOD:00012");
+        break;
+
+        // AminoAcidChar::proline,
+      case 'P':
+        aa_insert = getInstance("MOD:00024");
+        break;
+
+        // AminoAcidChar::glutamine,
+      case 'Q':
+        aa_insert = getInstance("MOD:00016");
+        break;
+        // AminoAcidChar::serine,
+      case 'S':
+        aa_insert = getInstance("MOD:00025");
+        break;
+
+        // AminoAcidChar::threonine,
+      case 'T':
+        aa_insert = getInstance("MOD:00026");
+        break;
+
+
+        // AminoAcidChar::valine,
+      case 'V':
+        aa_insert = getInstance("MOD:00029");
+        break;
+
+        // AminoAcidChar::tryptophan,
+      case 'W':
+        aa_insert = getInstance("MOD:00027");
+        break;
+
+        // AminoAcidChar::tyrosine,
+      case 'Y':
+        aa_insert = getInstance("MOD:00028");
+        break;
+        // AminoAcidChar::selenocysteine,
+      case 'U':
+        aa_insert = getInstance("MOD:00031");
+        break;
+      default:
+        throw ExceptionNotFound(
+          QObject::tr("ERROR getting removal accession instance of amino acid: "
+                      "%1 NOT FOUND")
+            .arg(amino_acid));
+    }
+
+  return aa_insert;
+}
+
 AaModificationP
 AaModification::getInstance(const OboPsiModTerm &oboterm)
 {
