@@ -253,6 +253,29 @@ QualifiedMassSpectrum::getPrecursorMz(bool *ok_p) const
   return m_precursorIonData.front().mz;
 }
 
+//! Get the precursor mass ratio.
+double
+QualifiedMassSpectrum::getPrecursorMass(bool *ok_p) const
+{
+  if(ok_p != nullptr)
+    *ok_p = false;
+  bool ok_precmz = false;
+  double mz_prec = getPrecursorMz(&ok_precmz);
+  if(ok_precmz)
+    {
+      uint charge = getPrecursorCharge(&ok_precmz);
+      if(ok_precmz)
+        {
+          // compute precursor mass given the charge state
+          mz_prec = mz_prec * (double)charge;
+          mz_prec -= MHPLUS * (double)charge;
+          if(ok_p != nullptr)
+            *ok_p = true;
+          return mz_prec;
+        }
+    }
+  return std::numeric_limits<double>::max();
+}
 
 QString
 QualifiedMassSpectrum::getPrecursorDataMzValuesAsString(
@@ -317,10 +340,9 @@ QualifiedMassSpectrum::getPrecursorCharge(bool *ok_p) const
 {
   if(!m_precursorIonData.size())
     {
-      return std::numeric_limits<unsigned int>::max();
-
       if(ok_p != nullptr)
         *ok_p = false;
+      return std::numeric_limits<unsigned int>::max();
     }
 
   if(ok_p != nullptr)
@@ -382,10 +404,9 @@ QualifiedMassSpectrum::getPrecursorIntensity(bool *ok_p) const
 {
   if(!m_precursorIonData.size())
     {
-      return std::numeric_limits<double>::max();
-
       if(ok_p != nullptr)
         *ok_p = false;
+      return std::numeric_limits<double>::max();
     }
 
   if(ok_p != nullptr)
