@@ -1,4 +1,4 @@
-//#include <proteowizard/pwiz/data/msdata/DefaultReaderList.hpp>
+// #include <proteowizard/pwiz/data/msdata/DefaultReaderList.hpp>
 
 #include <QDebug>
 #include <QFile>
@@ -85,8 +85,8 @@ MsFileAccessor::getMsRunIds()
 
       // But the user might have configured one preferred reader type.
 
-      auto pref = m_preferedFileReaderTypeMap.find(m_fileFormat);
-      if(pref != m_preferedFileReaderTypeMap.end())
+      auto pref = m_preferredFileReaderTypeMap.find(m_fileFormat);
+      if(pref != m_preferredFileReaderTypeMap.end())
         {
           m_fileReaderType = pref->second;
         }
@@ -116,8 +116,8 @@ MsFileAccessor::getMsRunIds()
       m_fileFormat     = tims_file_reader.getFileFormat();
       m_fileReaderType = FileReaderType::tims;
 
-      auto pref = m_preferedFileReaderTypeMap.find(m_fileFormat);
-      if(pref != m_preferedFileReaderTypeMap.end())
+      auto pref = m_preferredFileReaderTypeMap.find(m_fileFormat);
+      if(pref != m_preferredFileReaderTypeMap.end())
         {
           m_fileReaderType = pref->second;
         }
@@ -154,10 +154,10 @@ MsFileAccessor::getMsRunIds()
 
 
 void
-MsFileAccessor::setPreferedFileReaderType(MzFormat format,
-                                          FileReaderType reader_type)
+MsFileAccessor::setPreferredFileReaderType(MzFormat format,
+                                           FileReaderType reader_type)
 {
-  auto ret = m_preferedFileReaderTypeMap.insert(
+  auto ret = m_preferredFileReaderTypeMap.insert(
     std::pair<MzFormat, FileReaderType>(format, reader_type));
 
   if(!ret.second)
@@ -169,11 +169,11 @@ MsFileAccessor::setPreferedFileReaderType(MzFormat format,
 
 
 FileReaderType
-MsFileAccessor::getPreferedFileReaderType(MzFormat format)
+MsFileAccessor::getpreferredFileReaderType(MzFormat format)
 {
-  auto ret = m_preferedFileReaderTypeMap.find(format);
+  auto ret = m_preferredFileReaderTypeMap.find(format);
 
-  if(ret != m_preferedFileReaderTypeMap.end())
+  if(ret != m_preferredFileReaderTypeMap.end())
     {
       return ret->second;
     }
@@ -189,6 +189,29 @@ MsFileAccessor::getFileReaderType() const
 }
 
 
+void
+MsFileAccessor::setSelectedMsRunIdIndex(std::size_t index)
+{
+  m_selectedMsRunIdIndex = index;
+}
+
+
+std::size_t
+MsFileAccessor::getSelectedMsRunIdIndex() const
+{
+  return m_selectedMsRunIdIndex;
+}
+
+
+MsRunIdCstSPtr 
+MsFileAccessor::getSelectedMsRunId()
+{
+  if(m_selectedMsRunIdIndex >= getMsRunIds().size())
+    throw PappsoException(QObject::tr("MsRunId request out-of-bound error."));
+  
+  return getMsRunIds().at(m_selectedMsRunIdIndex);
+}
+
 TimsMsRunReaderMs2SPtr
 MsFileAccessor::buildTimsMsRunReaderMs2SPtr()
 {
@@ -222,7 +245,7 @@ MsFileAccessor::buildTimsMsRunReaderMs2SPtr()
 
 
 MsRunReaderSPtr
-MsFileAccessor::msRunReaderSp(MsRunIdCstSPtr ms_run_id)
+MsFileAccessor::msRunReaderSPtr(MsRunIdCstSPtr ms_run_id)
 {
   // We want to return a MsRunReader that accounts for the configuration that
   // the user might have set.
@@ -232,31 +255,32 @@ MsFileAccessor::msRunReaderSp(MsRunIdCstSPtr ms_run_id)
       QObject::tr("The MsRunId instance must have the name file name as the "
                   "MsFileAccessor.")));
 
-  if(getPreferedFileReaderType(m_fileFormat) == FileReaderType::pwiz)
+  if(getpreferredFileReaderType(m_fileFormat) == FileReaderType::pwiz)
     {
       // qDebug() << "Returning a PwizMsRunReader.";
 
       return std::make_shared<PwizMsRunReader>(ms_run_id);
     }
-  else if(getPreferedFileReaderType(m_fileFormat) == FileReaderType::xy)
+  else if(getpreferredFileReaderType(m_fileFormat) == FileReaderType::xy)
     {
       // qDebug() << "Returning a XyMsRunReader.";
 
       return std::make_shared<XyMsRunReader>(ms_run_id);
     }
-  else if(getPreferedFileReaderType(m_fileFormat) == FileReaderType::tims)
+  else if(getpreferredFileReaderType(m_fileFormat) == FileReaderType::tims)
     {
       // qDebug() << "Returning a TimsMsRunReader.";
 
       return std::make_shared<TimsMsRunReader>(ms_run_id);
     }
-  else if(getPreferedFileReaderType(m_fileFormat) == FileReaderType::tims_frames)
+  else if(getpreferredFileReaderType(m_fileFormat) ==
+          FileReaderType::tims_frames)
     {
       // qDebug() << "Returning a TimsFramesMsRunReader.";
 
       return std::make_shared<TimsFramesMsRunReader>(ms_run_id);
     }
-  else if(getPreferedFileReaderType(m_fileFormat) == FileReaderType::tims_ms2)
+  else if(getpreferredFileReaderType(m_fileFormat) == FileReaderType::tims_ms2)
     {
       // qDebug() << "Returning a TimsMsRunReaderMs2.";
 
@@ -273,15 +297,37 @@ MsFileAccessor::msRunReaderSp(MsRunIdCstSPtr ms_run_id)
           return std::make_shared<PwizMsRunReader>(ms_run_id);
         }
     }
-    else
+  else
     {
       throw PappsoException(QObject::tr("No file format was found."));
     }
-    
+
   return nullptr;
 }
 
 
+MsRunReaderSPtr 
+MsFileAccessor::msRunReaderSPtr(std::size_t ms_run_id_index)
+{
+  std::vector<MsRunIdCstSPtr> ms_run_ids = getMsRunIds();
+  if(ms_run_id_index >= ms_run_ids.size())
+    throw PappsoException(QObject::tr("MsRunId request out-of-bound error."));
+  
+  return msRunReaderSPtr(ms_run_ids.at(ms_run_id_index));
+}
+
+
+MsRunReaderSPtr 
+MsFileAccessor::msRunReaderSPtrForSelectedMsRunIdIndex()
+{
+  std::vector<MsRunIdCstSPtr> ms_run_ids = getMsRunIds();
+  if(m_selectedMsRunIdIndex >= ms_run_ids.size())
+    throw PappsoException(QObject::tr("MsRunId request out-of-bound error."));
+  
+  return msRunReaderSPtr(ms_run_ids.at(m_selectedMsRunIdIndex));
+}
+
+
 MsRunReaderSPtr
 MsFileAccessor::buildMsRunReaderSPtr(MsRunIdCstSPtr ms_run_id)
 {
@@ -290,7 +336,7 @@ MsFileAccessor::buildMsRunReaderSPtr(MsRunIdCstSPtr ms_run_id)
 
 MsRunReaderSPtr
 MsFileAccessor::buildMsRunReaderSPtr(
-  MsRunIdCstSPtr ms_run_id, pappso::FileReaderType prefered_file_reader_type)
+  MsRunIdCstSPtr ms_run_id, pappso::FileReaderType preferred_file_reader_type)
 {
   QFile file(ms_run_id.get()->getFileName());
   if(!file.exists())
@@ -315,11 +361,11 @@ MsFileAccessor::buildMsRunReaderSPtr(
 
   else if(file_format == MzFormat::brukerTims)
     {
-      if(prefered_file_reader_type == pappso::FileReaderType::tims)
+      if(preferred_file_reader_type == pappso::FileReaderType::tims)
         {
           return std::make_shared<TimsMsRunReader>(ms_run_id);
         }
-      else if(prefered_file_reader_type == pappso::FileReaderType::tims_ms2)
+      else if(preferred_file_reader_type == pappso::FileReaderType::tims_ms2)
         {
           return std::make_shared<TimsMsRunReaderMs2>(ms_run_id);
         }
@@ -349,7 +395,7 @@ MsFileAccessor::getMsRunReaderSPtrByRunId(const QString &run_id,
           MsRunId new_run_id(*original_run_id.get());
           new_run_id.setXmlId(xml_id);
 
-          return msRunReaderSp(std::make_shared<MsRunId>(new_run_id));
+          return msRunReaderSPtr(std::make_shared<MsRunId>(new_run_id));
         }
     }
 
@@ -358,7 +404,7 @@ MsFileAccessor::getMsRunReaderSPtrByRunId(const QString &run_id,
       MsRunId new_run_id(*run_list[0].get());
       new_run_id.setXmlId(xml_id);
 
-      return msRunReaderSp(std::make_shared<MsRunId>(new_run_id));
+      return msRunReaderSPtr(std::make_shared<MsRunId>(new_run_id));
     }
 
 
