@@ -40,15 +40,21 @@ class PMSPP_LIB_DECL MsFileAccessor
    */
   FileReaderType getFileReaderType() const;
 
-  /** @brief given an mz format, explicitly set the prefered reader
+  /** @brief given an mz format, explicitly set the preferred reader
    */
-  void setPreferedFileReaderType(MzFormat format, FileReaderType reader_type);
-  FileReaderType getPreferedFileReaderType(MzFormat format);
-  
+  void setPreferredFileReaderType(MzFormat format, FileReaderType reader_type);
+  FileReaderType getpreferredFileReaderType(MzFormat format);
+
   std::vector<MsRunIdCstSPtr> getMsRunIds();
-
-  MsRunReaderSPtr msRunReaderSp(MsRunIdCstSPtr ms_run_id);
-
+  
+   void setSelectedMsRunIdIndex(std::size_t index);
+  std::size_t getSelectedMsRunIdIndex() const;
+  MsRunIdCstSPtr getSelectedMsRunId();
+  
+  MsRunReaderSPtr msRunReaderSPtr(MsRunIdCstSPtr ms_run_id);
+  MsRunReaderSPtr msRunReaderSPtr(std::size_t ms_run_id_index);
+  MsRunReaderSPtr msRunReaderSPtrForSelectedMsRunIdIndex();
+  
   /** @brief get an msrun reader by finding the run_id in file
    *
    * @param run_id identifier within file of the MSrun
@@ -74,13 +80,13 @@ class PMSPP_LIB_DECL MsFileAccessor
    * msrunid
    *
    * @param ms_run_id msrun identifier
-   * @param prefered_file_reader_type the prefered file reader type to use
+   * @param preferred_file_reader_type the preferred file reader type to use
    * (depending on the mz format)
    * @return msrun reader shared pointer
    */
   static MsRunReaderSPtr
   buildMsRunReaderSPtr(MsRunIdCstSPtr ms_run_id,
-                       pappso::FileReaderType prefered_file_reader_type);
+                       pappso::FileReaderType preferred_file_reader_type);
 
   /** @brief if possible, builds directly a dedicated Tims TOF tdf file reader
    */
@@ -98,7 +104,12 @@ class PMSPP_LIB_DECL MsFileAccessor
   // Type of the file reader that could load the file.
   FileReaderType m_fileReaderType;
 
-  std::map<MzFormat, FileReaderType> m_preferedFileReaderTypeMap;
+  std::map<MzFormat, FileReaderType> m_preferredFileReaderTypeMap;
+  
+  std::size_t m_selectedMsRunIdIndex;
 };
 
+typedef std::shared_ptr<MsFileAccessor> MsFileAccessorSPtr;
+typedef std::shared_ptr<const MsFileAccessor> MsFileAccessorCstSPtr;
+
 } // namespace pappso
