@@ -91,9 +91,10 @@ class PMSPP_LIB_DECL MsRunDataSetTree
                                                  NodeVector &nodes,
                                                  DataKind data_kind) const;
 
-  std::size_t addDataSetTreeNodesInsideDtRtPolygon(const SelectionPolygon &selectionPolygon,
-                                                 NodeVector &nodes,
-                                                 DataKind data_kind) const;
+  std::size_t
+  addDataSetTreeNodesInsideDtRtPolygon(const SelectionPolygon &selectionPolygon,
+                                       NodeVector &nodes,
+                                       DataKind data_kind) const;
 
   std::size_t removeDataSetTreeNodesOutsideDtRtRange(double start,
                                                      double end,
