@@ -114,6 +114,26 @@ MzxmlOutput::write(MsRunReader *p_msrunreader)
   qDebug();
 }
 
+void
+pappso::MzxmlOutput::write(const MsRunReadConfig &read_config,
+                           pappso::MsRunReader *p_msrunreader)
+{
+  qDebug();
+  m_monitor.setTotalSteps(p_msrunreader->spectrumListSize());
+  writeHeader(p_msrunreader);
+
+  Translater translater(this);
+
+  translater.setReadAhead(m_isReadAhead);
+
+  translater.setNeedMsLevelPeakList(1, !m_ms1IsMasked);
+  // translater.setNeedMsLevelPeakList(1, false);
+  // translater.setNeedMsLevelPeakList(2, false);
+  p_msrunreader->readSpectrumCollection2(read_config, translater);
+
+  m_monitor.setTotalSteps(0);
+}
+
 void
 MzxmlOutput::writeHeader(MsRunReader *p_msrunreader)
 {
@@ -329,13 +349,25 @@ MzxmlOutput::writeQualifiedMassSpectrum(
       mpa_outputStream->writeAttribute(
         "precursorScanNum",
         QString("%1").arg(getPrecursorScanNumber(spectrum)));
-      mpa_outputStream->writeAttribute(
-        "precursorIntensity",
-        QString::number(spectrum.getPrecursorIntensity(), 'f', 4));
-      mpa_outputStream->writeAttribute(
-        "precursorCharge", QString("%1").arg(spectrum.getPrecursorCharge()));
-      mpa_outputStream->writeCharacters(
-        QString::number(spectrum.getPrecursorMz(), 'f', 12));
+      bool ok;
+      double precursor_intensity = spectrum.getPrecursorIntensity(&ok);
+      if(ok)
+        {
+          mpa_outputStream->writeAttribute(
+            "precursorIntensity", QString::number(precursor_intensity, 'f', 4));
+        }
+      uint charge = spectrum.getPrecursorCharge(&ok);
+      if(ok)
+        {
+          mpa_outputStream->writeAttribute("precursorCharge",
+                                           QString("%1").arg(charge));
+        }
+      double precursor_mz = spectrum.getPrecursorMz(&ok);
+      if(ok)
+        {
+          mpa_outputStream->writeCharacters(
+            QString::number(precursor_mz, 'f', 12));
+        }
       mpa_outputStream->writeEndElement();
     }
 
@@ -352,7 +384,8 @@ MzxmlOutput::writeQualifiedMassSpectrum(
   mpa_outputStream->writeAttribute("byteOrder", "network");
   mpa_outputStream->writeAttribute("contentType", "m/z-int");
 
-  if(spectrum.getMassSpectrumCstSPtr().get() != nullptr)
+  if((spectrum.getMassSpectrumCstSPtr().get() != nullptr) &&
+     (!spectrum.isEmptyMassSpectrum()))
     {
       QByteArray byte_array;
       if(QSysInfo::ByteOrder == QSysInfo::LittleEndian)
