@@ -378,6 +378,17 @@ PwizMsRunReader::qualifiedMassSpectrumFromPwizSpectrumPtr(
 
       qualified_mass_spectrum.setMsLevel(msLevel);
 
+      if(!spectrum_p->scanList.scans[0].hasCVParam(
+           pwiz::msdata::MS_peak_list_scans))
+        {
+
+          qDebug() << spectrum_p->cvParam(pwiz::msdata::MS_peak_list_scans)
+                        .valueAs<double>();
+          qualified_mass_spectrum.setParameterValue(
+            QualifiedMassSpectrumParameter::ScanNumber,
+            spectrum_p->cvParam(pwiz::msdata::MS_peak_list_scans)
+              .valueAs<double>());
+        }
       // We want to know if this spectrum is a fragmentation spectrum obtained
       // from a selected precursor ion.
 
@@ -794,7 +805,8 @@ PwizMsRunReader::readSpectrumCollection2(
   [[maybe_unused]] const MsRunReadConfig &config,
   SpectrumCollectionHandlerInterface &handler)
 {
-  readSpectrumCollectionByMsLevel(handler, 0);
+  qDebug();
+  readSpectrumCollectionWithMsrunReadConfig(config, handler);
 }
 
 void
@@ -935,6 +947,144 @@ PwizMsRunReader::readSpectrumCollectionByMsLevel(
   handler.loadingEnded();
 }
 
+void
+PwizMsRunReader::readSpectrumCollectionWithMsrunReadConfig(
+  const MsRunReadConfig &config, SpectrumCollectionHandlerInterface &handler)
+{
+  qDebug();
+  acquireDevice();
+  // qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()";
+
+  // We want to iterate in the pwiz-spectrum-list and for each pwiz-spectrum
+  // create a pappso-spectrum (QualifiedMassSpectrum). Once the pappso mass
+  // spectrum has been fully qualified (that is, the member data have been
+  // set), it is transferred to the handler passed as parameter to this
+  // function for the consumer to do what it wants with it.
+
+  // Does the handler consuming the mass spectra read from file want these
+  // mass spectra to hold the binary data arrays (mz/i vectors)?
+
+  const bool want_binary_data = config.needPeakList();
+
+
+  std::string env;
+  env = setlocale(LC_ALL, "");
+  setlocale(LC_ALL, "C");
+
+
+  // We access the pwiz-mass-spectra via the spectrumListPtr that sits in the
+  // run member of msp_msData.
+
+  pwiz::msdata::SpectrumListPtr spectrum_list_p =
+    msp_msData->run.spectrumListPtr;
+
+  // We'll need it to perform the looping in the spectrum list.
+  std::size_t spectrum_list_size = spectrum_list_p.get()->size();
+
+  // qDebug() << "The spectrum list has size:" << spectrum_list_size;
+
+  // Inform the handler of the spectrum list so that it can handle feedback to
+  // the user.
+  handler.spectrumListHasSize(spectrum_list_size);
+
+  // Iterate in the full list of spectra.
+
+  for(std::size_t iter = 0; iter < spectrum_list_size; iter++)
+    {
+
+
+      // If the user of this reader instance wants to stop reading the
+      // spectra, then break this loop.
+      if(handler.shouldStop())
+        {
+          qDebug() << "The operation was cancelled. Breaking the loop.";
+          break;
+        }
+
+      // Get the native pwiz-spectrum from the spectrum list.
+      // Note that this pointer is a shared pointer from pwiz.
+
+      pwiz::msdata::SpectrumPtr native_pwiz_spectrum_sp =
+        getPwizSpectrumPtr(spectrum_list_p.get(), iter, want_binary_data);
+
+      /*
+       * we want to load metadata of the spectrum even if it does not contain
+       peaks
+
+       * if(!native_pwiz_spectrum_sp->hasBinaryData())
+              {
+                // qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ <<
+       "
+       ()"
+                //<< "native pwiz spectrum is empty, continuing.";
+                continue;
+              }
+              */
+
+      // Instantiate the mass spectrum id that will hold critical information
+      // like the the native id string and the spectrum index.
+
+      MassSpectrumId massSpectrumId(mcsp_msRunId, iter /* spectrum index*/);
+
+      // Get the spectrum native id as a QString to store it in the mass
+      // spectrum id class. This is will allow later to refer to the same
+      // spectrum starting back from the file.
+
+      QString native_id = QString::fromStdString(native_pwiz_spectrum_sp->id);
+      massSpectrumId.setNativeId(native_id);
+
+      // Finally, instantiate the qualified mass spectrum with its id. This
+      // function will continue performing pappso-spectrum detailed
+      // qualification.
+
+      bool ok = false;
+
+      QualifiedMassSpectrum qualified_mass_spectrum =
+        qualifiedMassSpectrumFromPwizSpectrumPtr(
+          massSpectrumId, native_pwiz_spectrum_sp.get(), want_binary_data, ok);
+
+      if(!ok)
+        {
+          // qDebug() << "Encountered a mass spectrum for which the returned "
+          //"status is bad.";
+          continue;
+        }
+
+      // Before handing the mass spectrum out to the handler, see if the
+      // native mass spectrum was empty or not.
+
+      // if(!native_pwiz_spectrum_sp->defaultArrayLength)
+      // qDebug() << "The mass spectrum has not defaultArrayLength";
+
+      qualified_mass_spectrum.setEmptyMassSpectrum(
+        !native_pwiz_spectrum_sp->defaultArrayLength);
+
+      // The handler will receive the index of the mass spectrum in the
+      // current run via the mass spectrum id member datum.
+
+      qDebug();
+      if(config.acceptMsLevel(qualified_mass_spectrum.getMsLevel()))
+        {
+          if(config.acceptRetentionTimeInSeconds(
+               qualified_mass_spectrum.getRtInSeconds()))
+            {
+              handler.setQualifiedMassSpectrum(qualified_mass_spectrum);
+            }
+        }
+    }
+
+  setlocale(LC_ALL, env.c_str());
+  // End of
+  // for(std::size_t iter = 0; iter < spectrum_list_size; iter++)
+
+  // Now let the loading handler know that the loading of the data has ended.
+  // The handler might need this "signal" to perform additional tasks or to
+  // cleanup cruft.
+
+  // qDebug() << "Loading ended";
+  handler.loadingEnded();
+}
+
 std::size_t
 PwizMsRunReader::spectrumListSize() const
 {
