@@ -203,6 +203,14 @@ TimsMsRunReaderMs2::readSpectrumCollection(
   readSpectrumCollectionByMsLevel(handler, 0);
 }
 
+void
+TimsMsRunReaderMs2::readSpectrumCollection2(
+  [[maybe_unused]] const MsRunReadConfig &config,
+  [[maybe_unused]] SpectrumCollectionHandlerInterface &handler)
+{
+  readSpectrumCollectionByMsLevel(handler, 0);
+}
+
 void
 TimsMsRunReaderMs2::readSpectrumCollectionByMsLevel(
   SpectrumCollectionHandlerInterface &handler, unsigned int ms_level)
@@ -217,11 +225,11 @@ TimsMsRunReaderMs2::readSpectrumCollectionByMsLevel(
   // the user.
   handler.spectrumListHasSize(spectrum_list_size);
 
-
   msp_timsData.get()->setMonoThread(isMonoThread());
 
   msp_timsData.get()->ms2ReaderSpectrumCollectionByMsLevel(
     getMsRunId(), handler, ms_level);
+
   // Now let the loading handler know that the loading of the data has ended.
   // The handler might need this "signal" to perform additional tasks or to
   // cleanup cruft.
