@@ -39,6 +39,10 @@ class PMSPP_LIB_DECL OboPsiModTerm
   OboPsiModTerm &operator=(const OboPsiModTerm &);
 
   bool isValid() const;
+  /** @brief tells if this term "is_a" another accession
+   * @return bool if true
+   */
+  bool isA(const QString &accession) const;
 
   public:
   QString m_accession;
@@ -47,9 +51,13 @@ class PMSPP_LIB_DECL OboPsiModTerm
   QString m_psiModLabel;
   QString m_psiMsLabel;
   QString m_diffFormula;
+  QString m_formula;
   QString m_origin;
 
   double m_diffMono;
+  double m_massMono;
+
+  QStringList m_isA;
 
   private:
   void parseLine(const QString &line);
@@ -63,5 +71,4 @@ class PMSPP_LIB_DECL OboPsiModTerm
 } // namespace pappso
 
 
-
 extern int oboPsiModTermMetaTypeId;
