@@ -11,7 +11,10 @@
 
 
 /////////////////////// Local includes
+#include "../../types.h"
+#include "selectionpolygon.h"
 #include "../../trace/maptrace.h"
+#include "../../massspectrum/qualifiedmassspectrum.h"
 #include "../filters/filterresample.h"
 #include "../../exportinmportconfig.h"
 
@@ -19,7 +22,6 @@
 namespace pappso
 {
 
-
 class PMSPP_LIB_DECL MassDataCombinerInterface
 {
 
@@ -30,22 +32,16 @@ class PMSPP_LIB_DECL MassDataCombinerInterface
   void setDecimalPlaces(int value);
   int getDecimalPlaces() const;
 
-  void setFilterResampleKeepXRange(const FilterResampleKeepXRange &range);
+  using Iterator = std::vector<const Trace *>::const_iterator;
+  virtual MapTrace &combine(MapTrace &map_trace, Iterator begin, Iterator end);
 
   virtual MapTrace &combine(MapTrace &map_trace, const Trace &trace) const = 0;
   virtual MapTrace &combine(MapTrace &map_trace_out,
                             const MapTrace &map_trace_in) const            = 0;
 
-  using Iterator = std::vector<const Trace *>::const_iterator;
-  virtual MapTrace &combine(MapTrace &map_trace, Iterator begin, Iterator end);
-
   protected:
   //! Number of decimals to use for the keys (x values)
   int m_decimalPlaces = -1;
-
-  bool m_isApplyXRangeFilter = false;
-
-  FilterResampleKeepXRange m_filterXRange;
 };
 
 
