@@ -32,10 +32,12 @@ class PMSPP_LIB_DECL MassSpectrumPlusCombiner : public MassSpectrumCombiner
 
   virtual ~MassSpectrumPlusCombiner();
 
-  protected:
-  private:
-  virtual MapTrace &combineNoFilteringStep(MapTrace &map_trace,
-                                           const Trace &trace) const;
+  MassSpectrumPlusCombiner &operator=(const MassSpectrumPlusCombiner &other);
+
+  virtual MapTrace &combine(MapTrace &map_trace,
+                            const Trace &trace) const override;
+  virtual MapTrace &combine(MapTrace &map_trace_out,
+                            const MapTrace &map_trace_in) const override;
 };
 
 
