@@ -491,9 +491,9 @@ SelectionPolygon::contains(const QPointF &tested_point) const
   if(tested_point.x() < m_minX || tested_point.x() > m_maxX ||
      tested_point.y() < m_minY || tested_point.y() > m_maxY)
     {
-      //qDebug() << "Testing point:" << tested_point
-               //<< "aginst polygon:" << toString()
-               //<< "is out of x and y ranges.";
+      // qDebug() << "Testing point:" << tested_point
+      //<< "aginst polygon:" << toString()
+      //<< "is out of x and y ranges.";
       return false;
     }
 
@@ -507,7 +507,7 @@ SelectionPolygon::contains(const QPointF &tested_point) const
 
   if(isRectangle())
     {
-      //qDebug() << "Selection polygon *is* rectangle.";
+      // qDebug() << "Selection polygon *is* rectangle.";
 
       double x = tested_point.x();
       double y = tested_point.y();
@@ -519,16 +519,16 @@ SelectionPolygon::contains(const QPointF &tested_point) const
 
       bool res = x >= m_minX && x <= m_maxX && y >= m_minY && y <= m_maxY;
 
-      //qDebug() << qSetRealNumberPrecision(10) << "Returning: " << res
-               //<< "for point:" << tested_point
-               //<< "and selection polygon:" << toString();
+      // qDebug() << qSetRealNumberPrecision(10) << "Returning: " << res
+      //<< "for point:" << tested_point
+      //<< "and selection polygon:" << toString();
 
       return res;
     }
 
-  //qDebug() << "Testing point:" << tested_point
-           //<< "aginst polygon:" << toString()
-           //<< "is tested against a skewed selection polygon rectangle.";
+  // qDebug() << "Testing point:" << tested_point
+  //<< "aginst polygon:" << toString()
+  //<< "is tested against a skewed selection polygon rectangle.";
 
   // At this point, we know the selection polygon is not rectangle, we have to
   // make the real check using the point-in-polygon algorithm.
@@ -556,12 +556,12 @@ SelectionPolygon::contains(const QPointF &tested_point) const
         is_inside = !is_inside;
     }
 
-  //if(is_inside)
-    //qDebug() << "Testing point:" << tested_point
-             //<< "aginst polygon:" << toString() << "turns out be in.";
-  //else
-    //qDebug() << "Testing point:" << tested_point
-             //<< "aginst polygon:" << toString() << "turns out be out.";
+  // if(is_inside)
+  // qDebug() << "Testing point:" << tested_point
+  //<< "aginst polygon:" << toString() << "turns out be in.";
+  // else
+  // qDebug() << "Testing point:" << tested_point
+  //<< "aginst polygon:" << toString() << "turns out be out.";
 
   return is_inside;
 }
@@ -756,24 +756,28 @@ SelectionPolygon::toString() const
       text += QString("(%1,%2)\n").arg(x_string).arg(y_string);
     }
 
-  if(m_minX != std::numeric_limits<double>::min() && m_minX != std::numeric_limits<double>::max())
+  if(m_minX != std::numeric_limits<double>::min() &&
+     m_minX != std::numeric_limits<double>::max())
     text += QString("minX: %1 - ").arg(m_minX, 0, 'f', 10);
-  else 
+  else
     text += QString("minX: NOT_SET - ");
 
-  if(m_maxX != std::numeric_limits<double>::min() && m_maxX != std::numeric_limits<double>::max())
+  if(m_maxX != std::numeric_limits<double>::min() &&
+     m_maxX != std::numeric_limits<double>::max())
     text += QString("maxX: %1 - ").arg(m_maxX, 0, 'f', 10);
-  else 
+  else
     text += QString("maxX: NOT_SET - ");
 
-  if(m_minY != std::numeric_limits<double>::min() && m_minY != std::numeric_limits<double>::max())
+  if(m_minY != std::numeric_limits<double>::min() &&
+     m_minY != std::numeric_limits<double>::max())
     text += QString("minY: %1 - ").arg(m_minY, 0, 'f', 10);
-  else 
+  else
     text += QString("minY: NOT_SET - ");
 
-  if(m_maxY != std::numeric_limits<double>::min() && m_maxY != std::numeric_limits<double>::max())
+  if(m_maxY != std::numeric_limits<double>::min() &&
+     m_maxY != std::numeric_limits<double>::max())
     text += QString("maxY: %1 - ").arg(m_maxY, 0, 'f', 10);
-  else 
+  else
     text += QString("maxY: NOT_SET - ");
 
   return text;
@@ -1138,4 +1142,3 @@ SelectionPolygon::reorderPoints()
 }
 
 #endif
-
