@@ -166,14 +166,12 @@ struct PMSPP_LIB_DECL SelectionPolygonSpec
 
   SelectionPolygonSpec(const SelectionPolygon &selection_polygon,
                        DataKind data_kind)
-    : selectionPolygon(selection_polygon),
-      dataKind(data_kind)
+    : selectionPolygon(selection_polygon), dataKind(data_kind)
   {
   }
 
   SelectionPolygonSpec(const SelectionPolygonSpec &other)
-    : selectionPolygon(other.selectionPolygon),
-      dataKind(other.dataKind)
+    : selectionPolygon(other.selectionPolygon), dataKind(other.dataKind)
   {
   }
 
@@ -213,4 +211,3 @@ struct PMSPP_LIB_DECL SelectionPolygonSpec
 
 
 } // namespace pappso
-
