@@ -79,7 +79,7 @@ pappso::FilterMzExclusion::filter(pappso::Trace &data_points) const
 {
   qDebug();
   qDebug() << "before" << data_points.size();
-  data_points.sortY();
+  data_points.sortY(SortOrder::descending);
 
   Trace new_trace = removeTraceInExclusionMargin(data_points);
   new_trace.sortX();
