@@ -80,8 +80,8 @@ FilterLowIntensitySignalRemoval::~FilterLowIntensitySignalRemoval()
 
 
 FilterLowIntensitySignalRemoval &
-FilterLowIntensitySignalRemoval::
-operator=(const FilterLowIntensitySignalRemoval &other)
+FilterLowIntensitySignalRemoval::operator=(
+  const FilterLowIntensitySignalRemoval &other)
 {
   if(&other == this)
     return *this;
@@ -129,19 +129,19 @@ FilterLowIntensitySignalRemoval::detectClusterApices(const Trace &trace)
   std::size_t trace_size = trace.size();
   if(trace_size <= 2)
     {
-      //qDebug() << "The original trace has less than 3 points. Returning it "
-                  //"without modification.";
+      // qDebug() << "The original trace has less than 3 points. Returning it "
+      //"without modification.";
       return m_clusters.size();
     }
-  //else
-    //qDebug() << "The original trace has" << trace_size << "data points";
+  // else
+  // qDebug() << "The original trace has" << trace_size << "data points";
 
   // Seed the system with the first point of the trace.
   m_curIter  = trace.cbegin();
   m_prevIter = trace.cbegin();
 
-  //qDebug() << "First trace point: "
-           //<< "(" << m_prevIter->x << "," << m_prevIter->y << ");";
+  // qDebug() << "First trace point: "
+  //<< "(" << m_prevIter->x << "," << m_prevIter->y << ");";
 
   // We still have not found any apex!
   m_prevApex = trace.cend();
@@ -161,21 +161,21 @@ FilterLowIntensitySignalRemoval::detectClusterApices(const Trace &trace)
 
   while(m_curIter != trace.cend())
     {
-      //qDebug() << "Current trace point: "
-               //<< "(" << m_curIter->x << "," << m_curIter->y << ");";
+      // qDebug() << "Current trace point: "
+      //<< "(" << m_curIter->x << "," << m_curIter->y << ");";
 
       // We monitor if we are going up or down a peak.
 
       if(m_curIter->y > m_prevIter->y)
         // We are ascending a peak. We do not know if we are at the apex.
         {
-          //qDebug().noquote() << "We are ascending to an apex.\n";
+          // qDebug().noquote() << "We are ascending to an apex.\n";
           was_ascending_to_apex = true;
         }
       else
         // We are descending a peak.
         {
-          //qDebug().noquote() << "Descending a peak. ";
+          // qDebug().noquote() << "Descending a peak. ";
 
           // There are two situations:
           //
@@ -189,8 +189,8 @@ FilterLowIntensitySignalRemoval::detectClusterApices(const Trace &trace)
             {
               // Do nothing here.
 
-              //qDebug().noquote()
-                //<< "But, we were not ascending to an apex, so do nothing.\n";
+              // qDebug().noquote()
+              //<< "But, we were not ascending to an apex, so do nothing.\n";
             }
           else
             // We are effectively descending a peak right after the apex was
@@ -198,10 +198,10 @@ FilterLowIntensitySignalRemoval::detectClusterApices(const Trace &trace)
             {
               m_curApex = m_prevIter;
 
-              //qDebug().noquote()
-                //<< "And, we were ascending to an apex, so "
-                   //"m_curApex has become m_prevIter: ("
-                //<< m_curApex->x << "," << m_curApex->y << ")\n";
+              // qDebug().noquote()
+              //<< "And, we were ascending to an apex, so "
+              //"m_curApex has become m_prevIter: ("
+              //<< m_curApex->x << "," << m_curApex->y << ")\n";
 
               // We might have two situations:
 
@@ -230,16 +230,16 @@ FilterLowIntensitySignalRemoval::detectClusterApices(const Trace &trace)
                       // Store the crafted apices cluster.
                       m_clusters.push_back(cluster_apices);
 
-                      //qDebug().noquote()
-                        //<< "There was a previous apex already, BUT "
-                           //"outside of apices range. "
-                           //"Pushing the cooking apices that has size:"
-                        //<< cluster_apices->size();
+                      // qDebug().noquote()
+                      //<< "There was a previous apex already, BUT "
+                      //"outside of apices range. "
+                      //"Pushing the cooking apices that has size:"
+                      //<< cluster_apices->size();
 
                       // Now create a brand new apices for later work.
                       cluster_apices = std::make_shared<ClusterApices>();
 
-                      //qDebug() << "Created a brand new apices.";
+                      // qDebug() << "Created a brand new apices.";
 
                       // We only start the new apices with the current apex if
                       // that apex is above the threshold.
@@ -249,32 +249,32 @@ FilterLowIntensitySignalRemoval::detectClusterApices(const Trace &trace)
                           // And start it with the current apex.
                           cluster_apices->push_back(m_curApex);
 
-                          //qDebug()
-                            //<< "Since the current apex is above the threshold, "
-                               //"we PUSH it to the newly created apices: ("
-                            //<< m_curApex->x << "," << m_curApex->y << ")";
+                          // qDebug()
+                          //<< "Since the current apex is above the threshold, "
+                          //"we PUSH it to the newly created apices: ("
+                          //<< m_curApex->x << "," << m_curApex->y << ")";
 
                           m_prevApex = m_curApex;
 
-                          //qDebug() << "Set prev apex to be cur apex.";
+                          // qDebug() << "Set prev apex to be cur apex.";
                         }
                       else
                         {
-                          //qDebug()
-                            //<< "Since the current apex is below the threshold, "
-                               //"we DO NOT push it to the newly created "
-                               //"apices: ("
-                            //<< m_curApex->x << "," << m_curApex->y << ")";
+                          // qDebug()
+                          //<< "Since the current apex is below the threshold, "
+                          //"we DO NOT push it to the newly created "
+                          //"apices: ("
+                          //<< m_curApex->x << "," << m_curApex->y << ")";
 
                           // Since previous apex went to the closed apices, we
                           // need to reset it.
 
                           m_prevApex = trace.cend();
 
-                          //qDebug() << "Since the previous apex went to the "
-                                      //"closed apices, and cur apex has too "
-                                      //"small an intensity, we reset prev apex "
-                                      //"to trace.cend().";
+                          // qDebug() << "Since the previous apex went to the "
+                          //"closed apices, and cur apex has too "
+                          //"small an intensity, we reset prev apex "
+                          //"to trace.cend().";
                         }
                     }
                   else
@@ -290,31 +290,31 @@ FilterLowIntensitySignalRemoval::detectClusterApices(const Trace &trace)
                         {
                           cluster_apices->push_back(m_curApex);
 
-                          //qDebug().noquote()
-                            //<< "There was an apex already inside of apices "
-                               //"range. "
-                               //"AND, since the current apex was above the "
-                               //"threshold, we indeed push it to apices.\n";
+                          // qDebug().noquote()
+                          //<< "There was an apex already inside of apices "
+                          //"range. "
+                          //"AND, since the current apex was above the "
+                          //"threshold, we indeed push it to apices.\n";
 
-                          //qDebug().noquote()
-                            //<< "Current apex PUSHED: " << m_curApex->x << ", "
-                            //<< m_curApex->y;
+                          // qDebug().noquote()
+                          //<< "Current apex PUSHED: " << m_curApex->x << ", "
+                          //<< m_curApex->y;
 
                           m_prevApex = m_curApex;
 
-                          //qDebug() << "We set prev apex to be cur apex.";
+                          // qDebug() << "We set prev apex to be cur apex.";
                         }
                       else
                         {
-                          //qDebug().noquote()
-                            //<< "There was an apex already inside of apices "
-                               //"range. "
-                               //"BUT, since the current apex was below the "
-                               //"threshold, we do not push it to apices.\n";
+                          // qDebug().noquote()
+                          //<< "There was an apex already inside of apices "
+                          //"range. "
+                          //"BUT, since the current apex was below the "
+                          //"threshold, we do not push it to apices.\n";
 
-                          //qDebug().noquote()
-                            //<< "Current apex NOT pushed: " << m_curApex->x
-                            //<< ", " << m_curApex->y;
+                          // qDebug().noquote()
+                          //<< "Current apex NOT pushed: " << m_curApex->x
+                          //<< ", " << m_curApex->y;
                         }
                     }
                 }
@@ -332,23 +332,23 @@ FilterLowIntensitySignalRemoval::detectClusterApices(const Trace &trace)
 
                       cluster_apices->push_back(m_curApex);
 
-                      //qDebug().noquote()
-                        //<< "No previous apex was found. Since current apex' "
-                           //"intensity is above threshold, we push it back to "
-                           //"the "
-                           //"apices.\n";
+                      // qDebug().noquote()
+                      //<< "No previous apex was found. Since current apex' "
+                      //"intensity is above threshold, we push it back to "
+                      //"the "
+                      //"apices.\n";
 
                       // Store current apex as previous apex for next rounds.
                       m_prevApex = m_curApex;
 
-                      //qDebug().noquote() << "And thus we store the current "
-                                            //"apex as previous apex.\n";
+                      // qDebug().noquote() << "And thus we store the current "
+                      //"apex as previous apex.\n";
                     }
                   else
                     {
-                      //qDebug().noquote()
-                        //<< "No previous apex was found. Since current apex' "
-                           //"intensity is below threshold, we do nothing.\n";
+                      // qDebug().noquote()
+                      //<< "No previous apex was found. Since current apex' "
+                      //"intensity is below threshold, we do nothing.\n";
                     }
                 }
             }
@@ -365,8 +365,8 @@ FilterLowIntensitySignalRemoval::detectClusterApices(const Trace &trace)
 
       // At this point, prepare next round.
 
-      //qDebug().noquote()
-        //<< "Preparing next round, with m_prevIter = m_curIter and ++index.\n";
+      // qDebug().noquote()
+      //<< "Preparing next round, with m_prevIter = m_curIter and ++index.\n";
 
       m_prevIter = m_curIter;
 
@@ -444,9 +444,9 @@ FilterLowIntensitySignalRemoval::backwardFindApex(const Trace &trace,
       --iter;
     }
 
-  //qDebug() << "Init m/z: " << init_iter->x
-           //<< "Returning m/z: " << last_apex_iter->x
-           //<< "at distance:" << std::distance(last_apex_iter, init_iter);
+  // qDebug() << "Init m/z: " << init_iter->x
+  //<< "Returning m/z: " << last_apex_iter->x
+  //<< "at distance:" << std::distance(last_apex_iter, init_iter);
 
   // At this point last_apex_iter is the same as the initial iter.
   return last_apex_iter;
@@ -549,7 +549,8 @@ FilterLowIntensitySignalRemoval::reconstructTrace(const Trace &trace)
   // m_clusters is a vector that contains vectors of Trace::const_iter.
   // Each vector in m_clusters should represent all the apices of a cluster.
 
-  //qDebug() << "Reconstructing trace with " << m_clusters.size() << "clusters.";
+  // qDebug() << "Reconstructing trace with " << m_clusters.size() <<
+  // "clusters.";
 
   Trace::const_iterator left_begin_iter = trace.cend();
   Trace::const_iterator right_end_iter  = trace.cend();
@@ -563,15 +564,15 @@ FilterLowIntensitySignalRemoval::reconstructTrace(const Trace &trace)
       Trace::const_iterator begin_iter = *(cluster_apices->begin());
       Trace::const_iterator end_iter   = *(std::prev(cluster_apices->end()));
 
-      //qDebug() << "Iterating in a new cluster apices with boundaries:"
-               //<< begin_iter->x << "-" << end_iter->x;
+      // qDebug() << "Iterating in a new cluster apices with boundaries:"
+      //<< begin_iter->x << "-" << end_iter->x;
 
       left_begin_iter =
         backwardFindApex(trace, begin_iter, INTRA_CLUSTER_INTER_PEAK_DISTANCE);
 
-      //qDebug() << "After backwardFindApex, left_begin_iter points to:"
-               //<< left_begin_iter->toString() << "with distance:"
-               //<< std::distance(left_begin_iter, begin_iter);
+      // qDebug() << "After backwardFindApex, left_begin_iter points to:"
+      //<< left_begin_iter->toString() << "with distance:"
+      //<< std::distance(left_begin_iter, begin_iter);
 
       right_end_iter = forwardFindApex(
         trace, end_iter, 1.5 * INTRA_CLUSTER_INTER_PEAK_DISTANCE);
@@ -585,9 +586,8 @@ FilterLowIntensitySignalRemoval::reconstructTrace(const Trace &trace)
       // Now reset the left and right iters to intensity 0 to avoid having
       // disgraceful oblique lines connnecting trace segments.
 
-      map_trace[left_begin_iter->x] = 0;
+      map_trace[left_begin_iter->x]           = 0;
       map_trace[std::prev(right_end_iter)->x] = 0;
-
     }
 
   return map_trace.toTrace();
@@ -597,7 +597,7 @@ FilterLowIntensitySignalRemoval::reconstructTrace(const Trace &trace)
 Trace &
 FilterLowIntensitySignalRemoval::filter(Trace &trace) const
 {
-  //qDebug();
+  // qDebug();
 
   // Horrible hack to have a non const filtering process.
   return const_cast<FilterLowIntensitySignalRemoval *>(this)->nonConstFilter(
@@ -608,20 +608,20 @@ FilterLowIntensitySignalRemoval::filter(Trace &trace) const
 Trace &
 FilterLowIntensitySignalRemoval::nonConstFilter(Trace &trace)
 {
-  //qDebug();
+  // qDebug();
 
   if(trace.size() <= 2)
     {
-      //qDebug() << "The original trace has less than 3 points. Returning it "
-                  //"without modification.";
+      // qDebug() << "The original trace has less than 3 points. Returning it "
+      //"without modification.";
       return trace;
     }
-  //else
-    //qDebug() << "The original trace had" << trace.size() << "data points";
+  // else
+  // qDebug() << "The original trace had" << trace.size() << "data points";
 
   std::size_t cluster_count = detectClusterApices(trace);
 
-  //qDebug() << "Number of detected cluster apices: " << cluster_count;
+  // qDebug() << "Number of detected cluster apices: " << cluster_count;
 
   if(!cluster_count)
     return trace;
