@@ -29,10 +29,14 @@
 #include "filtersuitestring.h"
 #include "filterchargedeconvolution.h"
 #include "filtercomplementionenhancer.h"
+#include "filterpass.h"
+#include "filtermorpho.h"
 #include <QStringList>
 #include <QDebug>
 #include "../../exception/exceptionnotrecognized.h"
 #include "filterexclusionmz.h"
+
+
 namespace pappso
 {
 FilterSuiteString::FilterSuiteString(const QString &strBuildParams)
@@ -61,6 +65,16 @@ FilterSuiteString::filter(pappso::Trace &data_points) const
   qDebug();
   return data_points;
 }
+
+
+QString
+pappso::FilterSuiteString::name() const
+{
+  // FIXME: check if this makes sense
+  return "Suite of filters";
+}
+
+
 QString
 FilterSuiteString::toString() const
 {
@@ -73,11 +87,12 @@ FilterSuiteString::toString() const
   return filter_str_list.join(" ");
 }
 
+
 void
 FilterSuiteString::buildFilterFromString(const QString &strBuildParams)
 {
   // qInfo() << strBuildParams;
-  QStringList filters = strBuildParams.split(" ", QString::SkipEmptyParts);
+  QStringList filters = strBuildParams.split(" ", Qt::SkipEmptyParts);
   for(QString filter_str : filters)
     {
       if(filter_str.startsWith("complementIonEnhancer|"))
@@ -95,6 +110,17 @@ FilterSuiteString::buildFilterFromString(const QString &strBuildParams)
           m_filterVector.push_back(
             std::make_shared<FilterMzExclusion>(filter_str));
         }
+      else if(filter_str.startsWith("passQuantileBasedRemoveY|"))
+        {
+          m_filterVector.push_back(
+            std::make_shared<FilterQuantileBasedRemoveY>(filter_str));
+        }
+
+      else if(filter_str.startsWith("antiSpike|"))
+        {
+          m_filterVector.push_back(
+            std::make_shared<FilterMorphoAntiSpike>(filter_str));
+        }
       else
         {
           throw pappso::ExceptionNotRecognized(
@@ -105,4 +131,22 @@ FilterSuiteString::buildFilterFromString(const QString &strBuildParams)
     }
 }
 
+void
+FilterSuiteString::addFilterFromString(const QString &strBuildParams)
+{
+  buildFilterFromString(strBuildParams);
+}
+
+
+FilterSuiteString::FilterNameType::const_iterator
+FilterSuiteString::begin()
+{
+  return m_filterVector.begin();
+};
+FilterSuiteString::FilterNameType::const_iterator
+FilterSuiteString::end()
+{
+  return m_filterVector.end();
+};
+
 } // namespace pappso
