@@ -53,12 +53,26 @@ class PMSPP_LIB_DECL FilterSuiteString : public FilterNameInterface
 
   pappso::Trace &filter(pappso::Trace &data_points) const override;
 
+  virtual QString name() const override;
   QString toString() const override;
 
+  /** @brief takes a string that describes filters to add
+   * @param strBuildParams string to build the filter
+   * "chargeDeconvolution|0.02dalton anotherFilter|param1;param2"
+   */
+  void addFilterFromString(const QString &strBuildParams);
+
+  using FilterNameType = std::vector<FilterNameInterfaceCstSPtr>;
+
+  FilterNameType::const_iterator begin();
+  FilterNameType::const_iterator end();
+
   protected:
   void buildFilterFromString(const QString &strBuildParams) override;
 
   private:
   std::vector<FilterNameInterfaceCstSPtr> m_filterVector;
 };
+
+typedef std::shared_ptr<FilterSuiteString> FilterSuiteStringSPtr;
 } // namespace pappso
