@@ -37,6 +37,7 @@
 #include <QVector>
 #include <QDebug>
 
+#include "../../exception/exceptionnotrecognized.h"
 
 #include "savgolfilter.h"
 
@@ -54,11 +55,21 @@ namespace pappso
 FilterSavitzkyGolay::FilterSavitzkyGolay(
   int nL, int nR, int m, int lD, bool convolveWithNr)
 {
-  m_nL             = nL;
-  m_nR             = nR;
-  m_m              = m;
-  m_lD             = lD;
-  m_convolveWithNr = convolveWithNr;
+  m_params.nL             = nL;
+  m_params.nR             = nR;
+  m_params.m              = m;
+  m_params.lD             = lD;
+  m_params.convolveWithNr = convolveWithNr;
+}
+
+
+FilterSavitzkyGolay::FilterSavitzkyGolay(const SavGolParams sav_gol_params)
+{
+  m_params.nL             = sav_gol_params.nL;
+  m_params.nR             = sav_gol_params.nR;
+  m_params.m              = sav_gol_params.m;
+  m_params.lD             = sav_gol_params.lD;
+  m_params.convolveWithNr = sav_gol_params.convolveWithNr;
 }
 
 
@@ -66,11 +77,11 @@ FilterSavitzkyGolay::FilterSavitzkyGolay(const FilterSavitzkyGolay &other)
 {
   // This function only copies the parameters, not the data.
 
-  m_nL             = other.m_nL;
-  m_nR             = other.m_nR;
-  m_m              = other.m_m;
-  m_lD             = other.m_lD;
-  m_convolveWithNr = other.m_convolveWithNr;
+  m_params.nL             = other.m_params.nL;
+  m_params.nR             = other.m_params.nR;
+  m_params.m              = other.m_params.m;
+  m_params.lD             = other.m_params.lD;
+  m_params.convolveWithNr = other.m_params.convolveWithNr;
 }
 
 
@@ -86,16 +97,45 @@ FilterSavitzkyGolay::operator=(const FilterSavitzkyGolay &other)
 
   // This function only copies the parameters, not the data.
 
-  m_nL             = other.m_nL;
-  m_nR             = other.m_nR;
-  m_m              = other.m_m;
-  m_lD             = other.m_lD;
-  m_convolveWithNr = other.m_convolveWithNr;
+  m_params.nL             = other.m_params.nL;
+  m_params.nR             = other.m_params.nR;
+  m_params.m              = other.m_params.m;
+  m_params.lD             = other.m_params.lD;
+  m_params.convolveWithNr = other.m_params.convolveWithNr;
 
   return *this;
 }
 
 
+FilterSavitzkyGolay::FilterSavitzkyGolay(const QString &parameters)
+{
+  buildFilterFromString(parameters);
+}
+
+
+void
+FilterSavitzkyGolay::buildFilterFromString(const QString &parameters)
+{
+  // Typical string: "Savitzky-Golay|15;15;4;0;false"
+  if(parameters.startsWith(QString("%1|").arg(name())))
+    {
+      QStringList params = parameters.split("|").back().split(";");
+
+      m_params.nL             = params.at(0).toInt();
+      m_params.nR             = params.at(1).toInt();
+      m_params.m              = params.at(2).toInt();
+      m_params.lD             = params.at(3).toInt();
+      m_params.convolveWithNr = (params.at(4) == "true" ? true : false);
+    }
+  else
+    {
+      throw pappso::ExceptionNotRecognized(
+        QString("Building of FilterSavitzkyGolay from string %1 failed")
+          .arg(parameters));
+    }
+}
+
+
 Trace &
 FilterSavitzkyGolay::filter(Trace &data_points) const
 {
@@ -109,7 +149,7 @@ FilterSavitzkyGolay::filter(Trace &data_points) const
   pappso_double *y_initial_data_p  = dvector(1, data_point_count);
   pappso_double *y_filtered_data_p = nullptr;
 
-  if(m_convolveWithNr)
+  if(m_params.convolveWithNr)
     y_filtered_data_p = dvector(1, 2 * data_point_count);
   else
     y_filtered_data_p = dvector(1, data_point_count);
@@ -139,7 +179,8 @@ FilterSavitzkyGolay::filter(Trace &data_points) const
 SavGolParams
 FilterSavitzkyGolay::getParameters() const
 {
-  return SavGolParams(m_nL, m_nR, m_m, m_lD, m_convolveWithNr);
+  return SavGolParams(
+    m_params.nL, m_params.nR, m_params.m, m_params.lD, m_params.convolveWithNr);
 }
 
 
@@ -147,14 +188,14 @@ FilterSavitzkyGolay::getParameters() const
 QString
 FilterSavitzkyGolay::toString() const
 {
-  return QString::asprintf(
-    "Savitzy-Golay filter parameters:\n"
-    "nL: %d ; nR: %d ; m: %d ; lD: %d ; convolveWithNr : %s",
-    m_nL,
-    m_nR,
-    m_m,
-    m_lD,
-    (m_convolveWithNr ? "true" : "false"));
+  return QString("%1|%2").arg(name()).arg(m_params.toString());
+}
+
+
+QString
+FilterSavitzkyGolay::name() const
+{
+  return "Savitzky-Golay";
 }
 
 
@@ -589,14 +630,15 @@ FilterSavitzkyGolay::sgcoeff(
 
 //! Perform the Savitzky-Golay filtering process.
 /*
-   The results are in the \c y_filtered_data_p C array of pappso_double values.
+   The results are in the \c y_filtered_data_p C array of pappso_double
+   values.
    */
 char
 FilterSavitzkyGolay::runFilter(double *y_data_p,
                                double *y_filtered_data_p,
                                int data_point_count) const
 {
-  int np = m_nL + 1 + m_nR;
+  int np = m_params.nL + 1 + m_params.nR;
   pappso_double *c;
   char retval;
 
@@ -609,46 +651,52 @@ FilterSavitzkyGolay::runFilter(double *y_data_p,
 #else
   int j;
   long int k;
-  c      = dvector(1, m_nL + m_nR + 1);
-  retval = sgcoeff(c, np, m_nL, m_nR, m_lD, m_m);
+  c      = dvector(1, m_params.nL + m_params.nR + 1);
+  retval = sgcoeff(c, np, m_params.nL, m_params.nR, m_params.lD, m_params.m);
   if(retval == 0)
     {
       qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
                << "retval is 0";
 
-      for(k = 1; k <= m_nL; k++)
+      for(k = 1; k <= m_params.nL; k++)
         {
-          for(y_filtered_data_p[k] = 0.0, j = -m_nL; j <= m_nR; j++)
+          for(y_filtered_data_p[k] = 0.0, j = -m_params.nL; j <= m_params.nR;
+              j++)
             {
               if(k + j >= 1)
                 {
                   y_filtered_data_p[k] +=
-                    c[(j >= 0 ? j + 1 : m_nR + m_nL + 2 + j)] * y_data_p[k + j];
+                    c[(j >= 0 ? j + 1 : m_params.nR + m_params.nL + 2 + j)] *
+                    y_data_p[k + j];
                 }
             }
         }
-      for(k = m_nL + 1; k <= data_point_count - m_nR; k++)
+      for(k = m_params.nL + 1; k <= data_point_count - m_params.nR; k++)
         {
-          for(y_filtered_data_p[k] = 0.0, j = -m_nL; j <= m_nR; j++)
+          for(y_filtered_data_p[k] = 0.0, j = -m_params.nL; j <= m_params.nR;
+              j++)
             {
               y_filtered_data_p[k] +=
-                c[(j >= 0 ? j + 1 : m_nR + m_nL + 2 + j)] * y_data_p[k + j];
+                c[(j >= 0 ? j + 1 : m_params.nR + m_params.nL + 2 + j)] *
+                y_data_p[k + j];
             }
         }
-      for(k = data_point_count - m_nR + 1; k <= data_point_count; k++)
+      for(k = data_point_count - m_params.nR + 1; k <= data_point_count; k++)
         {
-          for(y_filtered_data_p[k] = 0.0, j = -m_nL; j <= m_nR; j++)
+          for(y_filtered_data_p[k] = 0.0, j = -m_params.nL; j <= m_params.nR;
+              j++)
             {
               if(k + j <= data_point_count)
                 {
                   y_filtered_data_p[k] +=
-                    c[(j >= 0 ? j + 1 : m_nR + m_nL + 2 + j)] * y_data_p[k + j];
+                    c[(j >= 0 ? j + 1 : m_params.nR + m_params.nL + 2 + j)] *
+                    y_data_p[k + j];
                 }
             }
         }
     }
 
-  free_dvector(c, 1, m_nR + m_nL + 1);
+  free_dvector(c, 1, m_params.nR + m_params.nL + 1);
 #endif
 
   return (retval);
