@@ -427,7 +427,7 @@ TandemWrapperRun::convertOrginalMsData2mzXmlData(const QString &origin,
 {
   qDebug();
   pappso::MsFileAccessor origin_access(origin, "runa1");
-  origin_access.setPreferedFileReaderType(pappso::MzFormat::brukerTims,
+  origin_access.setPreferredFileReaderType(pappso::MzFormat::brukerTims,
                                           pappso::FileReaderType::tims_ms2);
   origin_access.getMsRunIds();
   m_mzFormat = origin_access.getFileFormat();
@@ -449,7 +449,7 @@ TandemWrapperRun::convertOrginalMsData2mzXmlData(const QString &origin,
         QObject::tr("Converting %1 to mzXML %2").arg(origin).arg(target));
       pappso::MsRunReaderSPtr p_reader;
       p_reader =
-        origin_access.msRunReaderSp(origin_access.getMsRunIds().front());
+        origin_access.msRunReaderSPtr(origin_access.getMsRunIds().front());
 
       pappso::TimsMsRunReaderMs2 *tims2_reader =
         dynamic_cast<pappso::TimsMsRunReaderMs2 *>(p_reader.get());
