@@ -53,7 +53,8 @@ struct PMSPP_LIB_DECL DataPoint
   QString toString(int decimals) const;
 };
 
-PMSPP_LIB_DECL QDataStream &operator<<(QDataStream &out, const DataPoint &dataPoint);
+PMSPP_LIB_DECL QDataStream &operator<<(QDataStream &out,
+                                       const DataPoint &dataPoint);
 PMSPP_LIB_DECL QDataStream &operator>>(QDataStream &out, DataPoint &dataPoint);
 } // namespace pappso
 
