@@ -169,7 +169,8 @@ class PMSPP_LIB_DECL Trace : public std::vector<DataPoint>
   size_t initialize(const std::vector<pappso_double> &xVector,
                     const std::vector<pappso_double> &yVector);
 
-  size_t initialize(const QString space_sep_text);
+  size_t initialize(const QString &x_text, const QString &y_text);
+  size_t initialize(const QString &space_sep_text);
 
   size_t initialize(const Trace &other);
 
@@ -194,20 +195,29 @@ class PMSPP_LIB_DECL Trace : public std::vector<DataPoint>
                       PrecisionPtr precision_p = nullptr) const;
 
   // const Peak & Spectrum::getLowestIntensity() const;
-  const DataPoint &minYDataPoint() const;
+  const DataPoint &minXDataPoint() const;
+  // was const Peak & Spectrum::getMaxIntensity() const;
+  const DataPoint &maxXDataPoint() const;
 
+  // const Peak & Spectrum::getLowestIntensity() const;
+  const DataPoint &minYDataPoint() const;
   // was const Peak & Spectrum::getMaxIntensity() const;
   const DataPoint &maxYDataPoint() const;
 
+  pappso_double minX() const;
+  pappso_double maxX() const;
   pappso_double minY() const;
+
   pappso_double maxY() const;
   pappso_double maxY(double mzStart, double mzEnd) const;
+
   pappso_double sumY() const;
   pappso_double sumY(double mzStart, double mzEnd) const;
 
   // was void Spectrum::sortByMz();
-  void sortX();
-  void sortY();
+  void sort(SortType sort_type, SortOrder sort_order = SortOrder::ascending);
+  void sortX(SortOrder sort_order = SortOrder::ascending);
+  void sortY(SortOrder sort_order = SortOrder::ascending);
   void unique();
   std::size_t removeZeroYDataPoints();
 
@@ -218,6 +228,9 @@ class PMSPP_LIB_DECL Trace : public std::vector<DataPoint>
   virtual Trace &filter(const FilterInterface &filter) final;
   QString toString() const;
 
+  QByteArray xAsBase64Encoded() const;
+  QByteArray yAsBase64Encoded() const;
+
   /** @brief find datapoint with exactly x value
    */
   std::vector<DataPoint>::const_iterator
