@@ -37,6 +37,7 @@
 
 /////////////////////// Local includes
 #include "types.h"
+#include "processing/specglob/types.h"
 #include "exportinmportconfig.h"
 
 
@@ -113,6 +114,18 @@ class PMSPP_LIB_DECL Utils
    */
   static QString mzFormatAsString(MzFormat mz_format);
   static QString fileReaderTypeAsString(FileReaderType file_reader_type);
+
+  /** @brief Convenience function to return a string describing the specglob
+  alingment type
+   * @return QString
+   */
+  static QString toString(specglob::SpectralAlignmentType type);
+
+  /** @brief Convenience function to return a string describing the specglob
+   * experimental spectrum data point
+   * @return QString
+   */
+  static QString toString(specglob::ExperimentalSpectrumDataPointType type);
 };
 
 } // namespace pappso
