@@ -148,7 +148,7 @@ sqrt(m)) + (0.000338743021989553 * m)
           .arg(__FUNCTION__)
           .arg(__LINE__));
     }
-  return (pow(res.x1.real(), 2) - m_mzCalibrationArr[4]);
+  return (pow(res.x1, 2) - m_mzCalibrationArr[4]);
 }
 
 quint32
