@@ -202,6 +202,7 @@ TimsData::TimsData(QDir timsDataDirectory)
       TimsFrameRecord &frame_record =
         m_mapFramesRecord[record.value(8).toULongLong()];
 
+      frame_record.frame_id            = record.value(8).toULongLong();
       frame_record.tims_offset         = record.value(0).toULongLong();
       frame_record.accumulation_time   = record.value(1).toDouble();
       frame_record.mz_calibration_id   = record.value(2).toULongLong();
@@ -570,8 +571,10 @@ TimsData::getTimsFrameCstSPtr(std::size_t timsId)
   else
     {
       throw ExceptionNotFound(
-        QObject::tr("ERROR MzCalibration database id %1 not found")
-          .arg(frame_record.mz_calibration_id));
+        QObject::tr(
+          "ERROR MzCalibration database id %1 not found for frame_id=%2")
+          .arg(frame_record.mz_calibration_id)
+          .arg(timsId));
     }
 
   tims_frame.get()->setAccumulationTime(frame_record.accumulation_time);
@@ -1029,7 +1032,7 @@ TimsData::getQualifiedMs1MassSpectrumByPrecursorId(
       if(want_binary_data)
         {
           combiner.combine(combiner_result,
-                           tims_frame.get()->cumulateScanToTrace(
+                           tims_frame.get()->cumulateScansToTrace(
                              spectrum_descr.scan_mobility_start,
                              spectrum_descr.scan_mobility_end));
 
@@ -1179,7 +1182,7 @@ TimsData::setMs1FilterCstSPtr(FilterInterfaceCstSPtr &filter)
 
 XicCoordTims
 TimsData::getXicCoordTimsFromPrecursorId(std::size_t precursor_id,
-                                                 PrecisionPtr precision_ptr)
+                                         PrecisionPtr precision_ptr)
 {
 
   qDebug();
@@ -1802,7 +1805,7 @@ while(qprecursor_list.next())
     {
 
 
-      TimsData *itself                                            = this;
+      TimsData *itself                                    = this;
       SpectrumCollectionHandlerInterface *pointer_handler = &handler;
 
 
@@ -1860,7 +1863,6 @@ while(qprecursor_list.next())
 }
 
 
-
 void
 TimsData::ms2ReaderGenerateMS1MS2Spectrum(
   const MsRunIdCstSPtr &msrun_id,
