@@ -259,27 +259,27 @@ TimsFrame::cumulateSingleScanIntensities(std::size_t scanNum) const
 /**
  * @brief ...
  *
- * @param scanNumBegin p_scanNumBegin:...
- * @param scanNumEnd p_scanNumEnd:...
+ * @param mobility_scan_begin p_mobility_scan_begin:...
+ * @param mobility_scan_end p_mobility_scan_end:...
  * @return quint64
  */
 quint64
-TimsFrame::cumulateScansIntensities(std::size_t scanNumBegin,
-                                    std::size_t scanNumEnd) const
+TimsFrame::cumulateScansIntensities(std::size_t mobility_scan_begin,
+                                    std::size_t mobility_scan_end) const
 {
   quint64 summed_intensities = 0;
 
-  // qDebug() << "begin scanNumBegin =" << scanNumBegin
-  //<< "scanNumEnd =" << scanNumEnd;
+  // qDebug() << "begin mobility_scan_begin =" << mobility_scan_begin
+  //<< "mobility_scan_end =" << mobility_scan_end;
 
   if(m_timsDataFrame.size() == 0)
     return summed_intensities;
 
   try
     {
-      std::size_t imax = scanNumEnd + 1;
+      std::size_t mobility_scan_max = mobility_scan_end + 1;
 
-      for(std::size_t i = scanNumBegin; i < imax; i++)
+      for(std::size_t i = mobility_scan_begin; i < mobility_scan_max; i++)
         {
           qDebug() << i;
           summed_intensities += cumulateSingleScanIntensities(i);
@@ -290,8 +290,8 @@ TimsFrame::cumulateScansIntensities(std::size_t scanNumBegin,
     {
       qDebug() << QString("Failure in %1 %2 to %3 :\n %4")
                     .arg(__FUNCTION__)
-                    .arg(scanNumBegin)
-                    .arg(scanNumEnd)
+                    .arg(mobility_scan_begin)
+                    .arg(mobility_scan_end)
                     .arg(error.what());
     }
 
@@ -309,20 +309,77 @@ TimsFrame::cumulateScan(std::size_t scanNum,
 
   if(m_timsDataFrame.size() == 0)
     return;
+
   // checkScanNum(scanNum);
 
-  std::size_t size = getNbrPeaks(scanNum);
+  std::size_t scan_size = getNbrPeaks(scanNum);
 
-  std::size_t offset = getScanOffset(scanNum);
+  std::size_t scan_offset = getScanOffset(scanNum);
 
   qint32 previous = -1;
-  for(std::size_t i = 0; i < size; i++)
+  for(std::size_t i = 0; i < scan_size; i++)
     {
-      quint32 x =
-        (*(quint32 *)((m_timsDataFrame.constData() + (offset * 4) + (i * 8))) +
-         previous);
-      quint32 y = (*(quint32 *)(m_timsDataFrame.constData() + (offset * 4) +
-                                (i * 8) + 4));
+      quint32 x = (*(quint32 *)((m_timsDataFrame.constData() +
+                                 (scan_offset * 4) + (i * 8))) +
+                   previous);
+      quint32 y = (*(quint32 *)(m_timsDataFrame.constData() +
+                                (scan_offset * 4) + (i * 8) + 4));
+
+      previous = x;
+
+      auto ret = accumulate_into.insert(std::pair<quint32, quint32>(x, y));
+
+      if(ret.second == false)
+        {
+          // already existed : cumulate
+          ret.first->second += y;
+        }
+    }
+
+  // qDebug();
+}
+
+// Proof of concept m/z range-conditions for accumulations
+void
+TimsFrame::cumulateScan2(std::size_t scanNum,
+                         std::map<quint32, quint32> &accumulate_into,
+                         double mz_range_begin,
+                         double mz_range_end,
+                         quint32 accepted_tof_index_range_begin,
+                         quint32 accepted_tof_index_range_end) const
+{
+  // qDebug();
+
+  if(m_timsDataFrame.size() == 0)
+    return;
+
+  // checkScanNum(scanNum);
+
+  std::size_t scan_size   = getNbrPeaks(scanNum);
+  std::size_t scan_offset = getScanOffset(scanNum);
+  qint32 previous         = -1;
+
+  for(std::size_t i = 0; i < scan_size; i++)
+    {
+      quint32 x = (*(quint32 *)((m_timsDataFrame.constData() +
+                                 (scan_offset * 4) + (i * 8))) +
+                   previous);
+
+      if(x < accepted_tof_index_range_begin)
+        {
+          // qDebug() << "TOF index still not in range, x:" << x;
+          continue;
+        }
+      if(x > accepted_tof_index_range_end)
+        {
+          // qDebug() << "TOF index already out of range, x:" << x;
+          break;
+        }
+
+      // qDebug() << "TOF index in range, x:" << x;
+
+      quint32 y = (*(quint32 *)(m_timsDataFrame.constData() +
+                                (scan_offset * 4) + (i * 8) + 4));
 
       previous = x;
 
@@ -340,8 +397,8 @@ TimsFrame::cumulateScan(std::size_t scanNum,
 
 
 Trace
-TimsFrame::cumulateScanToTrace(std::size_t scanNumBegin,
-                               std::size_t scanNumEnd) const
+TimsFrame::cumulateScansToTrace(std::size_t mobility_scan_begin,
+                               std::size_t mobility_scan_end) const
 {
   // qDebug();
 
@@ -354,9 +411,9 @@ TimsFrame::cumulateScanToTrace(std::size_t scanNumBegin,
       std::map<quint32, quint32> raw_spectrum;
       // double local_accumulationTime = 0;
 
-      std::size_t imax = scanNumEnd + 1;
+      std::size_t mobility_scan_max = mobility_scan_end + 1;
       qDebug();
-      for(std::size_t i = scanNumBegin; i < imax; i++)
+      for(std::size_t i = mobility_scan_begin; i < mobility_scan_max; i++)
         {
           // qDebug() << i;
           cumulateScan(i, raw_spectrum);
@@ -392,29 +449,244 @@ TimsFrame::cumulateScanToTrace(std::size_t scanNumBegin,
     {
       qDebug() << QString(
                     "Failure in TimsFrame::cumulateScanToTrace %1 to %2 :\n %3")
-                    .arg(scanNumBegin, scanNumEnd)
+                    .arg(mobility_scan_begin, mobility_scan_end)
                     .arg(error.what());
     }
   return new_trace;
 }
 
+Trace
+TimsFrame::cumulateScansToTraceMzDownResolution(
+  std::size_t mz_index_merge_window,
+  std::size_t mobility_scan_begin,
+  std::size_t mobility_scan_end,
+  quint32 &mz_minimum_index_out,
+  quint32 &mz_maximum_index_out) const
+{
+  // qDebug();
+
+  Trace new_trace;
+
+  try
+    {
+      if(m_timsDataFrame.size() == 0)
+        {
+          qDebug() << "The frame is empty, returning empty trace.";
+          return new_trace;
+        }
+
+      // Allocate a map for (TOF,intensity) pairs to
+      // accumulate ion mobility scans.
+
+      std::map<quint32, quint32> raw_spectrum;
+      // double local_accumulationTime = 0;
+
+      std::size_t mobility_scan_max = mobility_scan_end + 1;
+
+      for(std::size_t i = mobility_scan_begin; i < mobility_scan_max; i++)
+        {
+          // qDebug() << "Going to cumulate currently iterated mobility scan:"
+          // << i;
+          cumulateScan(i, raw_spectrum);
+          // qDebug() << "Done cumulating currently iterated mobility scan:" <<
+          // i;
+
+          // local_accumulationTime += m_accumulationTime;
+        }
+
+      // qDebug();
+
+      pappso::DataPoint data_point_cumul;
+
+      MzCalibrationInterface *mz_calibration_p =
+        getMzCalibrationInterfaceSPtr().get();
+
+      // If the caller asks that m/z values be binned larger than they are,
+      // ask that the m/z raw map be reduced in resolution.
+      if(mz_index_merge_window > 0)
+        raw_spectrum = downsizeMzRawMap(mz_index_merge_window, raw_spectrum);
+
+      // Store the first mz index and the last mz index of the current spectrum.
+      // The values are set to the out parameters.
+      mz_minimum_index_out = std::numeric_limits<quint32>::max();
+      mz_maximum_index_out = 0;
+
+      for(std::pair<quint32, quint32> pair_tof_intensity : raw_spectrum)
+        {
+          if(pair_tof_intensity.first > mz_maximum_index_out)
+            mz_maximum_index_out = pair_tof_intensity.first;
+          if(pair_tof_intensity.first < mz_minimum_index_out)
+            mz_minimum_index_out = pair_tof_intensity.first;
+
+          // Convert the TOF index to m/z
+          data_point_cumul.x =
+            mz_calibration_p->getMzFromTofIndex(pair_tof_intensity.first);
+
+          // Normalization
+          data_point_cumul.y =
+            pair_tof_intensity.second * ((double)100.0 / m_accumulationTime);
+
+          // Finally make the data point a new Trace point.
+          new_trace.push_back(data_point_cumul);
+        }
+
+      // qDebug() << "At this point we have mz_minimum_index_out:"
+      //          << mz_minimum_index_out
+      //          << "and mz_maximum_index_out:" << mz_maximum_index_out;
+
+      // FIXME: this does not seem to be necessary since raw_spectrum is a map
+      // with auto-sorting on the keys which are quint32.
+      // new_trace.sortX();
+
+      // qDebug();
+    }
+  catch(std::exception &error)
+    {
+      qDebug() << QString(
+                    "Failure in TimsFrame::cumulateScanToTrace %1 to %2 :\n %3")
+                    .arg(mobility_scan_begin, mobility_scan_end)
+                    .arg(error.what());
+    }
+
+  // qDebug() << "Returning new trace of size:" << new_trace.size();
+
+  return new_trace;
+}
+
+
+Trace
+TimsFrame::cumulateScansToTraceMzDownResolution2(
+  std::size_t mz_index_merge_window,
+  double mz_range_begin,
+  double mz_range_end,
+  std::size_t mobility_scan_begin,
+  std::size_t mobility_scan_end,
+  quint32 &mz_minimum_index_out,
+  quint32 &mz_maximum_index_out) const
+{
+  // qDebug();
+
+  Trace new_trace;
+
+  try
+    {
+      if(m_timsDataFrame.size() == 0)
+        {
+          qDebug() << "The frame is empty, returning empty trace.";
+          return new_trace;
+        }
+
+      // Allocate a map for (TOF index,intensity) pairs to
+      // accumulate ion mobility scans.
+
+      std::map<quint32, quint32> raw_spectrum;
+      // double local_accumulationTime = 0;
+
+      std::size_t mobility_scan_max = mobility_scan_end + 1;
+
+      quint32 only_in_mz_begin_tof_index_range =
+        getMzCalibrationInterfaceSPtr().get()->getTofIndexFromMz(
+          mz_range_begin);
+      quint32 only_in_mz_end_tof_index_range =
+        getMzCalibrationInterfaceSPtr().get()->getTofIndexFromMz(mz_range_end);
+
+      // qDebug() << "20231129 TOF index range begin:"
+      //          << only_in_mz_begin_tof_index_range;
+      // qDebug() << "20231129 TOF index range end:"
+      //          << only_in_mz_end_tof_index_range;
+
+      for(std::size_t i = mobility_scan_begin; i < mobility_scan_max; i++)
+        {
+          // qDebug() << "Going to cumulate currently iterated mobility scan:"
+          // << i;
+          cumulateScan2(i,
+                        raw_spectrum,
+                        mz_range_begin,
+                        mz_range_end,
+                        only_in_mz_begin_tof_index_range,
+                        only_in_mz_end_tof_index_range);
+          // qDebug() << "Done cumulating currently iterated mobility scan:" <<
+          // i;
+
+          // local_accumulationTime += m_accumulationTime;
+        }
+
+      // qDebug();
+
+      pappso::DataPoint data_point_cumul;
+
+      MzCalibrationInterface *mz_calibration_p =
+        getMzCalibrationInterfaceSPtr().get();
+
+      // If the caller asks that m/z values be binned larger than they are,
+      // ask that the m/z raw map be reduced in resolution.
+      if(mz_index_merge_window > 0)
+        raw_spectrum = downsizeMzRawMap(mz_index_merge_window, raw_spectrum);
+
+      // Store the first mz index and the last mz index of the current spectrum.
+      // The values are set to the out parameters.
+      mz_minimum_index_out = std::numeric_limits<quint32>::max();
+      mz_maximum_index_out = 0;
+
+      for(std::pair<quint32, quint32> pair_tof_intensity : raw_spectrum)
+        {
+          if(pair_tof_intensity.first > mz_maximum_index_out)
+            mz_maximum_index_out = pair_tof_intensity.first;
+          if(pair_tof_intensity.first < mz_minimum_index_out)
+            mz_minimum_index_out = pair_tof_intensity.first;
+
+          // Convert the TOF index to m/z
+          data_point_cumul.x =
+            mz_calibration_p->getMzFromTofIndex(pair_tof_intensity.first);
+
+          // Normalization
+          data_point_cumul.y =
+            pair_tof_intensity.second * ((double)100.0 / m_accumulationTime);
+
+          // Finally make the data point a new Trace point.
+          new_trace.push_back(data_point_cumul);
+        }
+
+      // qDebug() << "At this point we have mz_minimum_index_out:"
+      //          << mz_minimum_index_out
+      //          << "and mz_maximum_index_out:" << mz_maximum_index_out;
+
+      // FIXME: this does not seem to be necessary since raw_spectrum is a map
+      // with auto-sorting on the keys which are quint32.
+      // new_trace.sortX();
+
+      // qDebug();
+    }
+  catch(std::exception &error)
+    {
+      qDebug() << QString(
+                    "Failure in TimsFrame::cumulateScanToTrace %1 to %2 :\n %3")
+                    .arg(mobility_scan_begin, mobility_scan_end)
+                    .arg(error.what());
+    }
+
+  // qDebug() << "Returning new trace of size:" << new_trace.size();
+
+  return new_trace;
+}
+
 
 void
 TimsFrame::cumulateScansInRawMap(std::map<quint32, quint32> &rawSpectrum,
-                                 std::size_t scanNumBegin,
-                                 std::size_t scanNumEnd) const
+                                 std::size_t mobility_scan_begin,
+                                 std::size_t mobility_scan_end) const
 {
-  // qDebug() << "begin scanNumBegin=" << scanNumBegin
-  //<< " scanNumEnd=" << scanNumEnd;
+  // qDebug() << "begin mobility_scan_begin=" << mobility_scan_begin
+  //<< " mobility_scan_end=" << mobility_scan_end;
 
   if(m_timsDataFrame.size() == 0)
     return;
   try
     {
 
-      std::size_t imax = scanNumEnd + 1;
+      std::size_t mobility_scan_max = mobility_scan_end + 1;
       qDebug();
-      for(std::size_t i = scanNumBegin; i < imax; i++)
+      for(std::size_t i = mobility_scan_begin; i < mobility_scan_max; i++)
         {
           qDebug() << i;
           cumulateScan(i, rawSpectrum);
@@ -427,8 +699,8 @@ TimsFrame::cumulateScansInRawMap(std::map<quint32, quint32> &rawSpectrum,
     {
       qDebug() << QString("Failure in %1 %2 to %3 :\n %4")
                     .arg(__FUNCTION__)
-                    .arg(scanNumBegin)
-                    .arg(scanNumEnd)
+                    .arg(mobility_scan_begin)
+                    .arg(mobility_scan_end)
                     .arg(error.what());
     }
 
