@@ -137,7 +137,7 @@ TimsFrameBase::getMassSpectrumSPtr(std::size_t scanNum) const
       .arg(scanNum));
 }
 Trace
-TimsFrameBase::cumulateScanToTrace(std::size_t scanNumBegin,
+TimsFrameBase::cumulateScansToTrace(std::size_t scanNumBegin,
                                    std::size_t scanNumEnd) const
 {
   throw PappsoException(
@@ -147,6 +147,20 @@ TimsFrameBase::cumulateScanToTrace(std::size_t scanNumBegin,
       .arg(scanNumEnd));
 }
 
+Trace
+TimsFrameBase::cumulateScansToTraceMzDownResolution(
+  std::size_t mzindex_merge_window [[maybe_unused]],
+  std::size_t scanNumBegin [[maybe_unused]],
+  std::size_t scanNumEnd [[maybe_unused]],
+  quint32 &minimum_index [[maybe_unused]],
+  quint32 &maximum_index [[maybe_unused]]) const
+{
+  throw PappsoException(QObject::tr("Non implemented function %1 %2 %3")
+                          .arg(__FILE__)
+                          .arg(__FUNCTION__)
+                          .arg(__LINE__));
+}
+
 void
 TimsFrameBase::cumulateScansInRawMap(std::map<quint32, quint32> &rawSpectrum
                                      [[maybe_unused]],
@@ -168,8 +182,9 @@ TimsFrameBase::cumulateSingleScanIntensities(std::size_t scanNum) const
   throw PappsoException(
     QObject::tr(
       "ERROR unable to cumulateSingleScanIntensities in TimsFrameBase for scan "
-      "number %1.").arg(scanNum));
-  
+      "number %1.")
+      .arg(scanNum));
+
   return 0;
 }
 
@@ -586,5 +601,25 @@ TimsFrameBase::getIonMobilityTraceByMzIndexRange(
   qDebug();
   return im_trace;
 }
+
+std::map<quint32, quint32> &
+TimsFrameBase::downsizeMzRawMap(std::size_t mzindex_merge_window,
+                                std::map<quint32, quint32> &rawSpectrum) const
+{
+  std::map<quint32, quint32> new_spectrum;
+
+  for(auto &pair_mz_intensity : rawSpectrum)
+    {
+      quint32 mzkey = (pair_mz_intensity.first / mzindex_merge_window);
+      mzkey   = (mzkey * mzindex_merge_window) + (mzindex_merge_window / 2);
+      auto it = new_spectrum.insert({mzkey, pair_mz_intensity.second});
+      if(it.second == false)
+        {
+          it.first->second += pair_mz_intensity.second;
+        }
+    }
+  rawSpectrum = new_spectrum;
+  return rawSpectrum;
+}
 // namespace pappso
 } // namespace pappso
