@@ -103,10 +103,41 @@ class TimsFrameBase
    * @param scanNumEnd scan number in the frame in the order it lies in binary
    * file, from 0 to N-1
    */
-  virtual Trace cumulateScanToTrace(std::size_t scanNumBegin,
+  virtual Trace cumulateScansToTrace(std::size_t scanNumBegin,
                                     std::size_t scanNumEnd) const;
 
 
+  /** @brief cumulate spectrum given a scan number range
+   * need the binary file
+   * The intensities are normalized with respect to the frame accumulation time
+   * to leverage computing performance, this function decreases the mz
+   * resolution
+   *
+   * @param mzindex_merge_window width of the mzindex window used to merge all
+   * intensities into a single point. This results in faster computing.
+   * @param scanNumBegin scan number in the frame in the order it lies in binary
+   * file, from 0 to N-1
+   * @param scanNumEnd scan number in the frame in the order it lies in binary
+   * file, from 0 to N-1
+   */
+  virtual Trace
+  cumulateScansToTraceMzDownResolution(std::size_t mzindex_merge_window,
+                                       std::size_t scanNumBegin,
+                                       std::size_t scanNumEnd,
+                                       quint32 &minimum_index,
+                                       quint32 &maximum_index) const;
+
+                                       
+  /** @brief downsize mz resolution to lower the number of real mz computations
+   *
+   * @param mzindex_merge_window width of the mzindex window used to merge all
+   * intensities into a single point. This results in faster computing.
+   * @param rawSpectrum the spectrum to shrink
+   */
+  std::map<quint32, quint32> &
+  downsizeMzRawMap(std::size_t mzindex_merge_window,
+                   std::map<quint32, quint32> &rawSpectrum) const;
+
   /** @brief cumulate scan list into a trace into a raw spectrum map
    * The intensities are NOT normalized with respect to the frame accumulation
    * time
@@ -121,6 +152,7 @@ class TimsFrameBase
                                      std::size_t scanNumBegin,
                                      std::size_t scanNumEnd) const;
 
+
   virtual quint64 cumulateSingleScanIntensities(std::size_t scanNum) const;
 
   virtual quint64 cumulateScansIntensities(std::size_t scanNumBegin,
