@@ -96,7 +96,8 @@ pappso::TimsDirectXicExtractor::protectedExtractXicCoordSPtrList(
       std::vector<XicCoordTims *>::iterator itXicListend =
         xic_coord_tims_list.end();
       qDebug();
-      TimsFrameCstSPtr frame_sptr = mp_timsData->getTimsFrameCstSPtr(frame_id);
+      TimsFrameCstSPtr frame_sptr =
+        mp_timsData->getTimsFrameCstSPtrCached(frame_id);
       qDebug();
       double rtframe = frame_sptr.get()->getTime();
       qDebug();
