@@ -169,9 +169,8 @@ class PMSPP_LIB_DECL BasePlotWidget : public QCustomPlot
   virtual void axisZoom();
   virtual void axisPan();
 
-  virtual void replotWithAxesRanges(QCPRange xAxisRange,
-                                    QCPRange yAxisRange,
-                                    Axis axis);
+  virtual void
+  replotWithAxesRanges(QCPRange xAxisRange, QCPRange yAxisRange, Axis axis);
 
   virtual void replotWithAxisRangeX(double lower, double upper);
   virtual void replotWithAxisRangeY(double lower, double upper);
