@@ -52,7 +52,7 @@ class PMSPP_LIB_DECL XicWidget : public GraphicDeviceWidget
   ~XicWidget();
 
 
-  void addXicSp(XicCstSPtr &xic_sp);
+  QCPGraph *addXicSp(XicCstSPtr xic_sp);
   void addMsMsEvent(const Xic *xic_p, pappso::pappso_double rt);
   void
   addXicPeakList(const Xic *xic_p,
