@@ -12,7 +12,7 @@ readMgf(const QString &filename)
       MsFileAccessor accessor(filename, "msrun");
       qDebug();
       MsRunReaderSPtr reader =
-        accessor.msRunReaderSp(accessor.getMsRunIds().front());
+        accessor.msRunReaderSPtr(accessor.getMsRunIds().front());
       qDebug() << accessor.getMsRunIds().front().get()->getXmlId();
       std::cout << __FILE__ << " " << __FUNCTION__ << " " << __LINE__ << " "
                 << reader->spectrumListSize() << std::endl;
@@ -44,7 +44,7 @@ readQualifiedMassSpectrumMgf(const QString &filename)
       MsFileAccessor accessor(filename, "msrun");
       qDebug();
       MsRunReaderSPtr reader =
-        accessor.msRunReaderSp(accessor.getMsRunIds().front());
+        accessor.msRunReaderSPtr(accessor.getMsRunIds().front());
       qDebug() << accessor.getMsRunIds().front().get()->getXmlId();
       std::cout << reader->spectrumListSize() << std::endl;
       QualifiedMassSpectrum spectrum_sp =
