@@ -31,7 +31,13 @@
 // valgrind --leak-check=yes ./tests/catch2-only-tests [TandemWrapperRun] -s
 
 
+#ifdef CATCH2_MAJOR_VERSION_2
 #include <catch2/catch.hpp>
+#elif CATCH2_MAJOR_VERSION_3
+#include <catch2/catch_all.hpp>
+using namespace Catch;
+#endif
+
 
 #include <QDebug>
 
@@ -61,7 +67,7 @@ TEST_CASE("running X!Tandem on tims raw data.", "[TandemWrapperRun]")
     }
 #elif USEPAPPSOTREE == 1
 
-  cout << std::endl << "..:: NO test TIMS TDF parsing ::.." << std::endl;
+  std::cout << std::endl << "..:: NO test TIMS TDF parsing ::.." << std::endl;
 
 #endif
 }
