@@ -31,7 +31,13 @@
 // ./tests/catch2-only-tests [rusconi] -s
 
 
+#ifdef CATCH2_MAJOR_VERSION_2
 #include <catch2/catch.hpp>
+#elif CATCH2_MAJOR_VERSION_3
+#include <catch2/catch_all.hpp>
+using namespace Catch;
+#endif
+
 
 #include <QDebug>
 #include <QThreadPool>
@@ -67,7 +73,7 @@ TEST_CASE("Check memory usage of tandemrun wrapper.", "[MemTandemWrapper]")
     }
 #elif USEPAPPSOTREE == 1
 
-  cout << std::endl << "..:: NO test TIMS TDF parsing ::.." << std::endl;
+  std::cout << std::endl << "..:: NO test TIMS TDF parsing ::.." << std::endl;
 
 #endif
 }
@@ -106,7 +112,7 @@ TEST_CASE("Check memory usage of timsdata reader.", "[MemTimsData]")
          .toStdString());
   pappso::MsRunReaderSPtr msrunA01 =
     file_access_A01.getMsRunReaderSPtrByRunId("", "runa01");
-  file_access_A01.setPreferedFileReaderType(pappso::MzFormat::brukerTims,
+  file_access_A01.setPreferredFileReaderType(pappso::MzFormat::brukerTims,
                                             pappso::FileReaderType::tims_ms2);
   file_access_A01.getMsRunIds();
 
@@ -116,7 +122,7 @@ TEST_CASE("Check memory usage of timsdata reader.", "[MemTimsData]")
 
   pappso::MsRunReaderSPtr p_reader;
   p_reader =
-    file_access_A01.msRunReaderSp(file_access_A01.getMsRunIds().front());
+    file_access_A01.msRunReaderSPtr(file_access_A01.getMsRunIds().front());
 
   pappso::TimsMsRunReaderMs2 *tims2_reader =
     dynamic_cast<pappso::TimsMsRunReaderMs2 *>(p_reader.get());
@@ -160,7 +166,7 @@ TEST_CASE("Check memory usage of timsdata reader.", "[MemTimsData]")
   mzxml_ouput.close();
 #elif USEPAPPSOTREE == 1
 
-  cout << std::endl << "..:: NO test TIMS TDF parsing ::.." << std::endl;
+  std::cout << std::endl << "..:: NO test TIMS TDF parsing ::.." << std::endl;
 
 #endif
 }
@@ -200,7 +206,7 @@ TEST_CASE("Check monothread usage of timsdata reader.", "[MonothreadTimsData]")
          .toStdString());
   pappso::MsRunReaderSPtr msrunA01 =
     file_access_A01.getMsRunReaderSPtrByRunId("", "runa01");
-  file_access_A01.setPreferedFileReaderType(pappso::MzFormat::brukerTims,
+  file_access_A01.setPreferredFileReaderType(pappso::MzFormat::brukerTims,
                                             pappso::FileReaderType::tims_ms2);
   file_access_A01.getMsRunIds();
 
@@ -210,7 +216,7 @@ TEST_CASE("Check monothread usage of timsdata reader.", "[MonothreadTimsData]")
 
   pappso::MsRunReaderSPtr p_reader;
   p_reader =
-    file_access_A01.msRunReaderSp(file_access_A01.getMsRunIds().front());
+    file_access_A01.msRunReaderSPtr(file_access_A01.getMsRunIds().front());
 
   pappso::TimsMsRunReaderMs2 *tims2_reader =
     dynamic_cast<pappso::TimsMsRunReaderMs2 *>(p_reader.get());
@@ -254,7 +260,7 @@ TEST_CASE("Check monothread usage of timsdata reader.", "[MonothreadTimsData]")
   mzxml_ouput.close();
 #elif USEPAPPSOTREE == 1
 
-  cout << std::endl << "..:: NO test TIMS TDF parsing ::.." << std::endl;
+  std::cout << std::endl << "..:: NO test TIMS TDF parsing ::.." << std::endl;
 
 #endif
 }
@@ -299,11 +305,11 @@ TEST_CASE("Check speed of timsdata reader.", "[rusconi]")
 
   pappso::MsRunReaderSPtr p_reader;
   p_reader =
-    file_access_A01.msRunReaderSp(file_access_A01.getMsRunIds().front());
+    file_access_A01.msRunReaderSPtr(file_access_A01.getMsRunIds().front());
 
 
   Trace tic = p_reader.get()->getTicChromatogram();
-  
+
   qWarning() << tic.toString();
   INFO(tic.toString().toStdString());
 /*
@@ -355,7 +361,7 @@ TEST_CASE("Check speed of timsdata reader.", "[rusconi]")
   */
 #elif USEPAPPSOTREE == 1
 
-  cout << std::endl << "..:: NO test TIMS TDF parsing ::.." << std::endl;
+  std::cout << std::endl << "..:: NO test TIMS TDF parsing ::.." << std::endl;
 
 #endif
 }
