@@ -34,7 +34,15 @@
 // ./tests/catch2-only-tests [AaStringCodec] -s
 
 
+#ifdef CATCH2_MAJOR_VERSION_2
 #include <catch2/catch.hpp>
+using namespace Catch;
+#elif CATCH2_MAJOR_VERSION_3
+#include <catch2/catch_all.hpp>
+using namespace Catch;
+using namespace Catch::Matchers;
+#endif
+
 #include <QDebug>
 #include <QString>
 #include <pappsomspp/mzrange.h>
@@ -58,22 +66,47 @@ TEST_CASE("Amino Acid test suite.", "[Aa]")
   // Set the debugging message formatting pattern.
   qSetMessagePattern(QString("%{file}@%{line}, %{function}(): %{message}"));
 
+  SECTION("..:: test PSI-MOD removal ::..", "[Aa]")
+  {
+    //%S << std::endl << "..:: AA init ::.." << std::endl;
+    //   OboPsiMod test;
+    Aa leucine('L');
+
+    REQUIRE(leucine.getMass() == Catch::Detail::Approx(113.084063979));
+
+    leucine.addAaModification(
+      AaModification::getInstanceRemovalAccessionByAaLetter('L'));
+    REQUIRE(leucine.getMass() == Catch::Detail::Approx(0.0));
+
+    leucine.addAaModification(
+      AaModification::getInstanceInsertionAccessionByAaLetter('M'));
+    REQUIRE(leucine.getMass() == Catch::Detail::Approx(131.0404850886));
+
+    REQUIRE(leucine.toProForma().toStdString() == "L[MOD:00022][MOD:01641]");
+
+    REQUIRE(leucine.getTotalModificationMass() ==
+            Catch::Detail::Approx(17.9564211096));
+    leucine.removeAllButInternalModification();
+
+    REQUIRE(leucine.toProForma().toStdString() == "L");
+  }
+
   SECTION("..:: AA init ::..", "[Aa]")
   {
-    // cout << std::endl << "..:: AA init ::.." << std::endl;
+    //%S << std::endl << "..:: AA init ::.." << std::endl;
     //   OboPsiMod test;
     Aa leucine('L');
     MzRange mz_range(leucine.getMass(), PrecisionFactory::getPpmInstance(1));
-    cout << "leucine: "
-         << QString::number(leucine.getMass(), 'g', 10).toStdString()
-         << std::endl;
-    cout << "leucine number of N15 : "
-         << leucine.getNumberOfIsotope(Isotope::N15) << std::endl;
-    cout << mz_range.toString().toStdString() << std::endl;
+    std::cout << "leucine: "
+              << QString::number(leucine.getMass(), 'g', 10).toStdString()
+              << std::endl;
+    std::cout << "leucine number of N15 : "
+              << leucine.getNumberOfIsotope(Isotope::N15) << std::endl;
+    std::cout << mz_range.toString().toStdString() << std::endl;
     /*
     if(!mz_range.contains(pappso_double(131.094635) - MASSH2O))
       {
-        cerr << QString::number(leucine.getMass(), 'g', 10).toStdString()
+        std::cerr << QString::number(leucine.getMass(), 'g', 10).toStdString()
              << " != 131.094635 - H2O";
         return 1;
       }
@@ -85,7 +118,7 @@ TEST_CASE("Amino Acid test suite.", "[Aa]")
     if(!MzRange(alanine.getMass(), PrecisionFactory::getPpmInstance(1))
           .contains(pappso_double(89.047676 - MASSH2O)))
       {
-        cerr << QString::number(alanine.getMass(), 'g', 10).toStdString()
+        std::cerr << QString::number(alanine.getMass(), 'g', 10).toStdString()
              << " != " << (89.047676 - MASSH2O);
         return 1;
       }
@@ -108,20 +141,21 @@ TEST_CASE("Amino Acid test suite.", "[Aa]")
 
     OboPsiMod psimod(filter_label);
 
-    cout << "term_list.size= " << term_list.size() << std::endl;
+    std::cout << "term_list.size= " << term_list.size() << std::endl;
     REQUIRE(term_list.size() == 12);
 
 
     MzRange range(pappso_double(57.02),
                   PrecisionFactory::getDaltonInstance(pappso_double(0.02)));
-    cout << range.getMz() << std::endl;
+    std::cout << range.getMz() << std::endl;
 
-    cout << "choses "
-         << MzRange(pappso_double(57.02),
-                    PrecisionFactory::getDaltonInstance(pappso_double(0.02)))
-              .toString()
-              .toStdString()
-         << std::endl;
+    std::cout << "choses "
+              << MzRange(
+                   pappso_double(57.02),
+                   PrecisionFactory::getDaltonInstance(pappso_double(0.02)))
+                   .toString()
+                   .toStdString()
+              << std::endl;
     FilterOboPsiModSink term_listb;
     FilterOboPsiModTermDiffMono filter_labelb(
       term_listb,
@@ -132,10 +166,10 @@ TEST_CASE("Amino Acid test suite.", "[Aa]")
 
     for(auto term : term_listb.getOboPsiModTermList())
       {
-        // cout << term._accession.toStdString() << " " << mz(term._diff_mono)
+        //%S << term._accession.toStdString() << " " << mz(term._diff_mono)
         // << std::endl;
       }
-    cout << "term_listb.size= " << term_listb.size() << std::endl;
+    std::cout << "term_listb.size= " << term_listb.size() << std::endl;
     REQUIRE(term_listb.size() == 8);
 
     Aa alaninebis('A');
@@ -172,42 +206,47 @@ TEST_CASE("Amino Acid test suite.", "[Aa]")
   SECTION("..:: Test Modifications ::..")
   {
     AaModificationP mod = AaModification::getInstance("MOD:00397");
-    cout << " MOD:00397 mass="
-         << QString::number(mod->getMass(), 'g', 15).toStdString() << std::endl;
+    std::cout << " MOD:00397 mass="
+              << QString::number(mod->getMass(), 'g', 15).toStdString()
+              << std::endl;
     // 57.021464
 
     // MOD:00429
     mod = AaModification::getInstance("MOD:00429");
-    cout << " MOD:00429 mass="
-         << QString::number(mod->getMass(), 'g', 15).toStdString() << std::endl;
+    std::cout << " MOD:00429 mass="
+              << QString::number(mod->getMass(), 'g', 15).toStdString()
+              << std::endl;
     // 28.0313
 
 
     // MOD:00382
     mod = AaModification::getInstance("MOD:00382");
-    cout << " MOD:00382 mass="
-         << QString::number(mod->getMass(), 'g', 15).toStdString() << std::endl;
+    std::cout << " MOD:00382 mass="
+              << QString::number(mod->getMass(), 'g', 15).toStdString()
+              << std::endl;
     //-20.026215
-    REQUIRE(mod->getMass() == Approx(-20.026215));
+    REQUIRE_THAT(mod->getMass(), WithinRel(-20.026215, 0.00001));
 
     // MOD:00234
     mod = AaModification::getInstance("MOD:00234");
-    cout << " MOD:00234 mass="
-         << QString::number(mod->getMass(), 'g', 15).toStdString() << std::endl;
+    std::cout << " MOD:00234 mass="
+              << QString::number(mod->getMass(), 'g', 15).toStdString()
+              << std::endl;
     // 305.068156
 
     // MOD:00838
     mod = AaModification::getInstance("MOD:00838");
-    cout << " MOD:00838 mass="
-         << QString::number(mod->getMass(), 'g', 15).toStdString() << std::endl;
+    std::cout << " MOD:00838 mass="
+              << QString::number(mod->getMass(), 'g', 15).toStdString()
+              << std::endl;
 
 
     for(auto amino_acid : pappso::Aa::getAminoAcidCharList())
       {
         pappso::Aa aa_enumi(amino_acid);
-        cout << " " << (char)amino_acid << " "
-             << QString::number(aa_enumi.getMass(), 'g', 15).toStdString()
-             << std::endl;
+        std::cout << " " << (char)amino_acid << " "
+                  << QString::number(aa_enumi.getMass(), 'g', 15).toStdString()
+                  << std::endl;
       }
     /*
      * A 71.037113785565
@@ -234,10 +273,14 @@ TEST_CASE("Amino Acid test suite.", "[Aa]")
     5:  U 168.964198469607
     5:  O 255.158291550141
     */
-    REQUIRE(pappso::Aa('A').getMass() == Approx(71.0371137856));
-    REQUIRE(pappso::Aa('R').getMass() == Approx(156.101111025652));
-    REQUIRE(pappso::Aa('C').getMass() == Approx(103.009184785565));
-    REQUIRE(pappso::Aa('D').getMass() == Approx(115.026943024685));
+    REQUIRE_THAT(pappso::Aa('A').getMass(),
+                 WithinAbs(71.0371137856, .0000000001));
+    REQUIRE_THAT(pappso::Aa('R').getMass(),
+                 WithinAbs(156.101111025652, .0000000001));
+    REQUIRE_THAT(pappso::Aa('C').getMass(),
+                 WithinAbs(103.0091849597, .0000000001));
+    REQUIRE_THAT(pappso::Aa('D').getMass(),
+                 WithinAbs(115.026943024685, .0000000001));
 
     // AaModification::getInstance("MOD:00397_wrong");
 
@@ -261,8 +304,8 @@ TEST_CASE("Amino Acid code test suite.", "[AaCode]")
   {
     AaCode aa_code;
 
-    REQUIRE(aa_code.getAa('C').getMass() ==
-            Approx(103.0091849597).margin(0.00001));
+    REQUIRE_THAT(aa_code.getAa('C').getMass(),
+                 WithinRel(103.0091849597, 0.00001));
     REQUIRE(aa_code.getAaCode('C') == 7);
 
     REQUIRE(aa_code.getAa((uint8_t)6).getMass() <
@@ -275,8 +318,8 @@ TEST_CASE("Amino Acid code test suite.", "[AaCode]")
     REQUIRE(aa_code.getAaCode('A') == 2);
     REQUIRE(aa_code.getAaCode('I') == 7);
 
-    REQUIRE(aa_code.getAa('C').getMass() ==
-            Approx(160.0306486807).margin(0.00001));
+    REQUIRE_THAT(aa_code.getAa('C').getMass(),
+                 WithinRel(160.0306486807, 0.00001));
     REQUIRE(aa_code.getAaCode('C') == 17);
 
     REQUIRE(aa_code.getAa((uint8_t)16).getMass() <
@@ -318,8 +361,7 @@ TEST_CASE("Amino Acid string codec test suite.", "[AaStringCodec]")
     REQUIRE(codec.codeLlc("SAM") == 873);
     REQUIRE(codec.decode(873).toStdString() == "MSA");
 
-    REQUIRE(codec.getMass(873) ==
-            Approx(codec.getMass(5243)).margin(0.0000001));
+    REQUIRE_THAT(codec.getMass(873), WithinRel(codec.getMass(5243), 0.0000001));
 
     std::vector<CodeToMass> arr_codemass =
       codec.generateLlcCodeListByMaxPeptideSize(3);
