@@ -26,16 +26,22 @@
  *implementation
  ******************************************************************************/
 
-// make test ARGS="-V -I 2,2"
+// ./tests/catch2-only-tests [Fasta] -s
 
-#define CATCH_CONFIG_MAIN
+
+#ifdef CATCH2_MAJOR_VERSION_2
 #include <catch2/catch.hpp>
+#elif CATCH2_MAJOR_VERSION_3
+#include <catch2/catch_all.hpp>
+using namespace Catch;
+#endif
+
 #include <iostream>
 #include <pappsomspp/fasta/fastareader.h>
 #include <pappsomspp/fasta/fastafileindexer.h>
 #include <pappsomspp/exception/exceptionoutofrange.h>
 #include <QFileInfo>
-//#include "common.h"
+// #include "common.h"
 #include "config.h"
 
 using namespace std;
@@ -58,9 +64,9 @@ class FastaSeq : public pappso::FastaHandlerInterface
   setSequence(const QString &description_in,
               const QString &sequence_in) override
   {
-    cout << std::endl << "begin description=" << description_in.toStdString();
-    cout << std::endl << "sequence=" << sequence_in.toStdString();
-    cout << std::endl << "end" << std::endl;
+    std::cout << std::endl << "begin description=" << description_in.toStdString();
+    std::cout << std::endl << "sequence=" << sequence_in.toStdString();
+    std::cout << std::endl << "end" << std::endl;
     description = description_in;
     sequence    = sequence_in;
   };
@@ -89,13 +95,13 @@ TEST_CASE("Fasta reader test suite.", "[Fasta]")
     /*
    Spectrum spectrum_low_masses(spectrum_parent.applyCutOff(150));
    if (! spectrum_low_masses.equals(sremove_low_masses, precision)) {
-       cerr << "spectrum_low_masses() != tandem"<< std::endl;
+       std::cerr << "spectrum_low_masses() != tandem"<< std::endl;
        return 1;
    }*/
   }
   SECTION("..:: Test Fasta file indexer ::..", "[FastaIndexer]")
   {
-    cout << std::endl << "..:: Test Fasta file indexer ::.." << std::endl;
+    std::cout << std::endl << "..:: Test Fasta file indexer ::.." << std::endl;
     QFileInfo file(QString(CMAKE_SOURCE_DIR)
                      .append("/tests/data/asr1_digested_peptides.txt"));
 
@@ -134,7 +140,7 @@ TEST_CASE("Fasta reader test suite.", "[Fasta]")
           "LLLEYLEEKYEEHLYER LTQSMAIIRYIADK KFELGLEFPNLPYYIDGDVK "
           "ERAEISMLEGAVLDIR");
 
-        cout << std::endl << " getSequenceByIndex(seq, 12) is OK " << std::endl;
+        std::cout << std::endl << " getSequenceByIndex(seq, 12) is OK " << std::endl;
       }
     catch(pappso::ExceptionOutOfRange &error)
       {
@@ -151,12 +157,12 @@ TEST_CASE("Fasta reader test suite.", "[Fasta]")
   SECTION("..:: Test Fasta big file indexer ::..", "[FastaBigIndexer]")
   {
     FastaSeq seq;
-    cout << std::endl << "..:: Test Fasta big file indexer ::.." << std::endl;
+    std::cout << std::endl << "..:: Test Fasta big file indexer ::.." << std::endl;
     QFileInfo file2("/gorgone/pappso/moulon/database/Genome_Z_mays_5a.fasta");
     pappso::FastaFileIndexer big_fasta_file_indexer(file2);
     big_fasta_file_indexer.getSequenceByIndex(seq, 12);
 
-    cout << std::endl << seq.getDescription().toStdString() << std::endl;
+    std::cout << std::endl << seq.getDescription().toStdString() << std::endl;
 
     // GRMZM2G147579_P01
     // GRMZM2G147579_P01 NP_001159186 hypothetical protein LOC100304271
@@ -189,7 +195,7 @@ TEST_CASE("Fasta reader test suite.", "[Fasta]")
     REQUIRE(seq.getDescription() == "YGR254W "); // YGR254W
     fuzzy_fasta_file_indexer.getSequenceByIndex(seq, 2);
 
-    cout << std::endl << seq.getDescription().toStdString() << std::endl;
+    std::cout << std::endl << seq.getDescription().toStdString() << std::endl;
 
     // GRMZM2G147579_P01
     // GRMZM2G147579_P01 NP_001159186 hypothetical protein LOC100304271
@@ -203,8 +209,8 @@ TEST_CASE("Fasta reader test suite.", "[Fasta]")
                                                    pappso::FastaFileIndexer fuzzy_macos_fasta_file_indexer(fuzzy_macos_file);
                                                    fuzzy_macos_fasta_file_indexer.getSequenceByIndex(seq, 0);
                                              
-                                                   cout << std::endl << "sequence0: " << seq.getDescription().toStdString() <<
-                                                   std::endl;
+                                                   std::cout << std::endl << "sequence0: " << seq.getDescription().toStdString()
+                                                   <<                                              std::endl;
                                              
                                                    // GRMZM2G147579_P01
                                                    // GRMZM2G147579_P01 NP_001159186 hypothetical protein LOC100304271
@@ -221,7 +227,7 @@ TEST_CASE("Fasta reader test suite.", "[Fasta]")
                                                      }
                                                    fuzzy_macos_fasta_file_indexer.getSequenceByIndex(seq, 2);
                                              
-                                                   cout << std::endl << "sequence2: "<< seq.getDescription().toStdString() <<
+                                                   std::cout << std::endl << "sequence2: "<< seq.getDescription().toStdString() <<
                                                    std::endl;
                                              
                                                    // GRMZM2G147579_P01
