@@ -26,11 +26,16 @@
  *implementation
  ******************************************************************************/
 
-// make test ARGS="-V -I 14,14"
+//  ./tests/catch2-only-tests [spectrumisotope] -s
 
 
-#define CATCH_CONFIG_MAIN
+#ifdef CATCH2_MAJOR_VERSION_2
 #include <catch2/catch.hpp>
+#elif CATCH2_MAJOR_VERSION_3
+#include <catch2/catch_all.hpp>
+using namespace Catch;
+#endif
+
 #include <pappsomspp/mzrange.h>
 #include <pappsomspp/peptide/peptidenaturalisotopelist.h>
 #include <pappsomspp/peptide/peptidefragmentionlistbase.h>
@@ -58,11 +63,11 @@ TEST_CASE("Isotope with spectrum test suite.", "[spectrumisotope]")
     MassSpectrum spectrum = readMgf(
       QString(CMAKE_SOURCE_DIR).append("/tests/data/peaklist_15046.mgf"));
 
-    cout << "spectrum size:" << spectrum.size() << std::endl;
+    std::cout << "spectrum size:" << spectrum.size() << std::endl;
 
     Peptide peptide("AIADGSLLDLLR");
 
-    list<PeptideIon> cid_ion = PeptideFragmentIonListBase::getCIDionList();
+    std::list<PeptideIon> cid_ion = PeptideFragmentIonListBase::getCIDionList();
     PeptideFragmentIonListBase frag_cid(peptide.makePeptideSp(), cid_ion);
     PeptideFragmentIonSp pep_frag_ion_sp =
       frag_cid.getPeptideFragmentIonSp(PeptideIon::y, 8);
@@ -84,13 +89,13 @@ TEST_CASE("Isotope with spectrum test suite.", "[spectrumisotope]")
                        PrecisionFactory::getPpmInstance(100))
                  .contains(peak.x))
               {
-                cout << std::endl
+                std::cout << std::endl
                      << isotope.get()->getIsotopeNumber()
                      << "..:: " << isotope.get()->getFormula(1).toStdString()
                      << " mz1=" << isotope.get()->getMz(1)
                      << " ratio=" << isotope.get()->getIntensityRatio(1)
                      << " ::.." << std::endl;
-                cout << " real mz=" << peak.x << " real intensity" << peak.y
+                std::cout << " real mz=" << peak.x << " real intensity" << peak.y
                      << std::endl;
               }
           }
@@ -99,10 +104,11 @@ TEST_CASE("Isotope with spectrum test suite.", "[spectrumisotope]")
 
     map_isotope_number = isotopeListFrag.getIntensityRatioPerIsotopeNumber();
 
-    cout << "isotope levels" << std::endl;
+    std::cout << "isotope levels" << std::endl;
     for(unsigned int i = 0; i < map_isotope_number.size(); i++)
       {
-        cout << "frag isotope " << i << " " << map_isotope_number[i] << std::endl;
+        std::cout << "frag isotope " << i << " " << map_isotope_number[i]
+             << std::endl;
       }
     /*
      0..:: C39H70O11N11S0 C13(0) H2(0) O17(0) O18(0) N15(0) S34(0) mz1=886.536
