@@ -1,4 +1,11 @@
+
+#ifdef CATCH2_MAJOR_VERSION_2
 #include <catch2/catch.hpp>
+#elif CATCH2_MAJOR_VERSION_3
+#include <catch2/catch_all.hpp>
+using namespace Catch;
+#endif
+
 
 #include <QDebug>
 
@@ -120,12 +127,14 @@ TEST_CASE("Create bins with Da-based bin size", "[MzIntegrationParams]")
     double manual_value = bins.front() + precision_p->delta(bins.front());
 
     // Below: if abs(1.0 - 1.2) is less or equal to 0.2 -> success
-    //REQUIRE_THAT(1.0, Catch::Matchers::WithinAbs(1.2, 0.2)); // success
-    //REQUIRE_THAT(1.2, Catch::Matchers::WithinAbs(1.1, 0.2)); // success
-    //REQUIRE_THAT(1.0, Catch::Matchers::WithinAbs(1.3, 0.2)); // failure
-    //REQUIRE_THAT(1.3, Catch::Matchers::WithinAbs(1.0, 0.2)); // failure
+    // REQUIRE_THAT(1.0, Catch::Matchers::WithinAbs(1.2, 0.2)); // success
+    // REQUIRE_THAT(1.2, Catch::Matchers::WithinAbs(1.1, 0.2)); // success
+    // REQUIRE_THAT(1.0, Catch::Matchers::WithinAbs(1.3, 0.2)); // failure
+    // REQUIRE_THAT(1.3, Catch::Matchers::WithinAbs(1.0, 0.2)); // failure
 
-    REQUIRE_THAT(bins.back(), Catch::Matchers::WithinAbs(manual_value, std::numeric_limits<double>::epsilon()*10));
+    REQUIRE_THAT(bins.back(),
+                 Catch::Matchers::WithinAbs(
+                   manual_value, std::numeric_limits<double>::epsilon() * 10));
   }
 }
 
@@ -216,4 +225,3 @@ TEST_CASE("Create bins with res-based bin sizes", "[MzIntegrationParams]")
     REQUIRE(bins.back() == 1800.374 + rounded_precision_delta);
   }
 }
-
