@@ -29,11 +29,19 @@
 // make test ARGS="-V -I 6,6"
 // ./tests/catch2-only-tests [Peptide] -s
 
+
+#ifdef CATCH2_MAJOR_VERSION_2
 #include <catch2/catch.hpp>
+#elif CATCH2_MAJOR_VERSION_3
+#include <catch2/catch_all.hpp>
+using namespace Catch;
+#endif
+
 #include <pappsomspp/mzrange.h>
 #include <pappsomspp/amino_acid/aa.h>
 #include <pappsomspp/peptide/peptide.h>
 #include <pappsomspp/peptide/peptidestrparser.h>
+#include <pappsomspp/peptide/peptideproformaparser.h>
 #include <iostream>
 #include <QDebug>
 #include <QString>
@@ -46,14 +54,29 @@ TEST_CASE("Test Peptide", "[Peptide]")
   // Set the debugging message formatting pattern.
   qSetMessagePattern(QString("%{file}@%{line}, %{function}(): %{message}"));
 
+  SECTION("..:: Test ProForma parser ::..", "[proforma]")
+  {
+    PeptideSp peptide_from_str = PeptideProFormaParser::parseString(
+      "C[MOD:00397][MOD:01160]C[MOD:00397]AADDKEAC[MOD:00397]FAVEGPK");
+    REQUIRE(peptide_from_str.get()->getMass() == Approx(1909.764470427));
+
+    PeptideSp peptide_from_str2 = PeptideProFormaParser::parseString(
+      "C[MOD:00397][MOD:01160]C[MOD:00397]AADDK[-18.02]EAC[MOD:00397]FAVEGPK");
+    /*REQUIRE(peptide_from_str2.get()->toProForma().toStdString() ==
+            "C[MOD:00397][MOD:01160]C[MOD:00397]AADDK[-18.0200]EAC[MOD:00397]"
+            "FAVEGPK");*/
+    REQUIRE(peptide_from_str2.get()->getMass() == Approx(1891.744470427));
+  }
+
+
   SECTION("..:: Test Peptide ::..", "[Peptide]")
   {
 
-    cout << std::endl << "..:: peptide init ::.." << std::endl;
+    std::cout << std::endl << "..:: peptide init ::.." << std::endl;
     Peptide peptide("LA");
-    cout << std::endl << "..:: peptide LI ::.." << std::endl;
-    cout << peptide.getSequence().toStdString() << " "
-         << peptide.getSequenceLi().toStdString() << std::endl;
+    std::cout << std::endl << "..:: peptide LI ::.." << std::endl;
+    std::cout << peptide.getSequence().toStdString() << " "
+              << peptide.getSequenceLi().toStdString() << std::endl;
     MzRange mz_range(peptide.getMass(), PrecisionFactory::getPpmInstance(10));
     REQUIRE(mz_range.contains(Aa('L').getMass() + Aa('A').getMass() + MASSH2O));
     // 202.13179
@@ -75,10 +98,6 @@ TEST_CASE("Test Peptide", "[Peptide]")
       <psimod position="1"  accession="MOD:01160"/>
       */
 
-    for(const pappso::Aa &amino_acid : peptide2)
-      {
-      }
-
     pappso::AaModificationP aaModcarba =
       AaModification::getInstance("MOD:00397");
     /*
@@ -90,7 +109,7 @@ TEST_CASE("Test Peptide", "[Peptide]")
     peptide2.addAaModification(aaModcarba, 9);
     peptide2.addAaModification(AaModification::getInstance("MOD:01160"), 0);
 
-    cerr << peptide2.getFormula(1).toStdString().c_str() << std::endl;
+    std::cerr << peptide2.getFormula(1).toStdString().c_str() << std::endl;
 
     MzRange mz_range2(peptide2.getMz(1), PrecisionFactory::getPpmInstance(10));
     REQUIRE(mz_range2.contains(1910.7722));
@@ -111,7 +130,7 @@ TEST_CASE("Test Peptide", "[Peptide]")
     // SUCCESS
     Peptide copy_str2(*peptide_from_str2.get());
     copy_str2.rotate();
-    cerr << copy_str2.toAbsoluteString().toStdString() << std::endl;
+    std::cerr << copy_str2.toAbsoluteString().toStdString() << std::endl;
     REQUIRE(peptide_from_str2.get()->getMass() == copy_str2.getMass());
 
 
@@ -119,7 +138,8 @@ TEST_CASE("Test Peptide", "[Peptide]")
     //[Term]
     // id: MOD:00582
     // name: 6x(13)C,2x(15)N labeled L-lysine
-    cout << std::endl << "..:: Test peptide isotope labels::.." << std::endl;
+    std::cout << std::endl
+              << "..:: Test peptide isotope labels::.." << std::endl;
     PeptideSp peptide_normal =
       PeptideStrParser::parseString("CCAALDDKEACFAVEGPK");
     PeptideSp peptide_lys_label =
@@ -145,7 +165,7 @@ TEST_CASE("Test Peptide", "[Peptide]")
     REQUIRE(peptide_lys_label_bis.get()->toString().toStdString() ==
             peptide_lys_label.get()->toString().toStdString());
 
-    cout << std::endl << "..:: peptide palindrome ::.." << std::endl;
+    std::cout << std::endl << "..:: peptide palindrome ::.." << std::endl;
     Peptide peptide_pal_a("ALA");
 
     REQUIRE(peptide_pal_a.isPalindrome());
@@ -153,7 +173,7 @@ TEST_CASE("Test Peptide", "[Peptide]")
     REQUIRE_FALSE(peptide_normal.get()->isPalindrome());
 
 
-    cout << std::endl << "..:: peptide dimethyl ::.." << std::endl;
+    std::cout << std::endl << "..:: peptide dimethyl ::.." << std::endl;
     //"Q(internal:Nter_hydrolytic_cleavage_H,MOD:00429)SLPSLSS(MOD:00696)FLNR(internal:Cter_hydrolytic_cleavage_HO)"
     Peptide peptide_dimethyl("QSLPSLSSFLNR");
     pappso::AaModificationP aaModDimethyl =
@@ -162,13 +182,13 @@ TEST_CASE("Test Peptide", "[Peptide]")
       AaModification::getInstance("MOD:00696");
     peptide_dimethyl.addAaModification(aaModDimethyl, 0);
     peptide_dimethyl.addAaModification(aaModDimethyl2, 7);
-    cout << "Before " << peptide_dimethyl.toAbsoluteString().toStdString();
-    cout << std::endl << "remove AaModif" << std::endl;
+    std::cout << "Before " << peptide_dimethyl.toAbsoluteString().toStdString();
+    std::cout << std::endl << "remove AaModif" << std::endl;
     peptide_dimethyl.removeAaModification(aaModDimethyl);
     REQUIRE(
       peptide_dimethyl.toAbsoluteString().toStdString() ==
       "Q(internal:Nter_hydrolytic_cleavage_H)SLPSLSS(MOD:00696)FLNR(internal:"
       "Cter_hydrolytic_cleavage_HO)");
-    cout << "Finish " << peptide_dimethyl.toAbsoluteString().toStdString();
+    std::cout << "Finish " << peptide_dimethyl.toAbsoluteString().toStdString();
   }
 }
