@@ -27,6 +27,19 @@
  ******************************************************************************/
 
 
+// ./tests/catch2-only-tests [peptidefragment] -s
+
+
+#ifdef CATCH2_MAJOR_VERSION_2
+#include <catch2/catch.hpp>
+using namespace Catch;
+#elif CATCH2_MAJOR_VERSION_3
+#include <catch2/catch_all.hpp>
+using namespace Catch;
+using namespace Catch::Matchers;
+#endif
+
+
 #include <pappsomspp/pappsoexception.h>
 #include <pappsomspp/mzrange.h>
 #include <pappsomspp/peptide/peptidefragment.h>
@@ -39,57 +52,39 @@
 using namespace pappso;
 using namespace std;
 
-int
-main()
+TEST_CASE("Peptide Fragment test suite.", "[peptidefragment]")
 {
+  // Set the debugging message formatting pattern.
+  qSetMessagePattern(QString("%{file}@%{line}, %{function}(): %{message}"));
+
+  SECTION("..:: test Peptide Fragment ::..", "[peptidefragment]")
+  {
+    std::cout << std::endl << "..:: peptide fragment init ::.." << std::endl;
+
+    PeptideFragment pep_fragment(
+      std::make_shared<Peptide>("PEPTIDE"), PeptideDirection::Cter, 4);
 
 
-  cout << std::endl << "..:: peptide fragment init ::.." << std::endl;
-
-  PeptideFragment pep_fragment(
-    std::make_shared<Peptide>("PEPTIDE"), PeptideDirection::Cter, 4);
+    REQUIRE(pep_fragment.getMass() == Catch::Detail::Approx(476.2118432465));
+    // SUCCESS
+    PeptideFragment pep_fragmentr(
+      std::make_shared<Peptide>("PEPTIDE"), PeptideDirection::Nter, 4);
 
 
-  cout << "pep_fragment" << pep_fragment.getMass();
-  // SUCCESS
-  PeptideFragment pep_fragmentr(
-    std::make_shared<Peptide>("PEPTIDE"), PeptideDirection::Nter, 4);
+    REQUIRE(pep_fragmentr.getMass() == Catch::Detail::Approx(442.2063639429));
+    REQUIRE(pep_fragmentr.getMz(1) == Catch::Detail::Approx(443.2136404098));
+    REQUIRE(pep_fragmentr.getMz(2) == Catch::Detail::Approx(222.1104584383));
 
+    REQUIRE_NOTHROW(PeptideFragmentIon(
+      std::make_shared<PeptideFragment>(
+        std::make_shared<Peptide>("PEPTIDE"), PeptideDirection::Nter, 4),
+      PeptideIon::a));
 
-  cout << "pep_fragmentr" << pep_fragmentr.getMass() << " z=1 "
-       << pep_fragmentr.getMz(1) << " z=2 " << pep_fragmentr.getMz(2) << std::endl;
-
-  try
-    {
-      PeptideFragmentIon ion(
+    REQUIRE_THROWS_AS(
+      PeptideFragmentIon(
         std::make_shared<PeptideFragment>(
           std::make_shared<Peptide>("PEPTIDE"), PeptideDirection::Nter, 4),
-        PeptideIon::a);
-    }
-  catch(const PappsoException &error)
-    {
-      cerr << "Oops! an error occurred. Dont Panic :" << std::endl;
-      cerr << error.qwhat().toStdString() << std::endl;
-      return 1;
-    }
-
-  try
-    {
-      PeptideFragmentIon ion(
-        std::make_shared<PeptideFragment>(
-          std::make_shared<Peptide>("PEPTIDE"), PeptideDirection::Nter, 4),
-        PeptideIon::y);
-    }
-  catch(const pappso::PappsoException &error)
-    {
-      cout << "ok, y ion is not Nter" << std::endl;
-      cout << error.qwhat().toStdString() << std::endl;
-    }
-  catch(const std::exception &error)
-    {
-      cout << "ok, y ion is not Nter" << std::endl;
-      cout << error.what() << std::endl;
-    }
-  // cout << pep_fragmentr.getMz(0);
-  return 0;
+        PeptideIon::y),
+      pappso::PappsoException);
+  }
 }
