@@ -29,7 +29,14 @@
 // make test ARGS="-V -I 3,3"
 // ./tests/catch2-only-tests [Protein] -s
 
+
+#ifdef CATCH2_MAJOR_VERSION_2
 #include <catch2/catch.hpp>
+#elif CATCH2_MAJOR_VERSION_3
+#include <catch2/catch_all.hpp>
+using namespace Catch;
+#endif
+
 #include <iostream>
 
 #include <pappsomspp/mzrange.h>
@@ -150,7 +157,7 @@ TEST_CASE("Test Protein", "[Protein]")
   {
 
     qDebug() << "init test protein";
-    cout << std::endl << "..:: Test Protein ::.." << std::endl;
+    std::cout << std::endl << "..:: Test Protein ::.." << std::endl;
 
     Protein cry1Ac(
       "cry1Ac",
@@ -186,7 +193,7 @@ TEST_CASE("Test Protein", "[Protein]")
       "SV"
       "YEEKSYTDGRRENPCEFNRGYRDYTPLPVGYVTKELEYFPETDKVWIEIGETEGTFIVDSVELLLMEE");
 
-    cout << std::endl << "cry1Ac Mass = " << cry1Ac.getMass() << std::endl;
+    std::cout << std::endl << "cry1Ac Mass = " << cry1Ac.getMass() << std::endl;
     MzRange cry1Ac_mass(133248.068195739,
                         PrecisionFactory::getPpmInstance(0.5));
     REQUIRE(cry1Ac_mass.contains(cry1Ac.getMass()));
@@ -282,7 +289,7 @@ TEST_CASE("Test Protein", "[Protein]")
     var_mod_builder.setSink(&modification_sink);
 
     //  QString accMo = "MOD:00719";
-    cout << std::endl << "..:: chose ::.." << std::endl;
+    std::cout << std::endl << "..:: chose ::.." << std::endl;
 
     PeptideBuilder fixed_mod_builder2;
     fixed_mod_builder2.setSink(&var_mod_builder);
@@ -302,7 +309,7 @@ TEST_CASE("Test Protein", "[Protein]")
     kinase.eat(0, fake, false, peptide_size2varmod);
 
     digestion.clear();
-    cout << std::endl
+    std::cout << std::endl
          << "..:: Test trypsin peptides on fake prot ::.." << std::endl;
     kinase.eat(0, fake, false, digestion);
 
@@ -316,7 +323,7 @@ TEST_CASE("Test Protein", "[Protein]")
     REQUIRE(digestion.size() == 6);
 
     // BSA
-    cout << std::endl
+    std::cout << std::endl
          << "..:: Test semi tryptic peptides on BSA ::.." << std::endl;
     kinase.setMiscleavage(0);
     PeptideSemiEnzyme semi_tryptic;
@@ -367,7 +374,7 @@ TEST_CASE("Test Protein", "[Protein]")
     kinase.eat(0, fake, false, peptide_size2varmod);
 
     // reverse protein :
-    cout << std::endl
+    std::cout << std::endl
          << "reverse :"
          << Protein(*fake.get()).reverse().getSequence().toStdString();
 
@@ -377,30 +384,30 @@ TEST_CASE("Test Protein", "[Protein]")
       peptide_test.get()->toString().toStdString() ==
       "E(MOD:00429)C(MOD:00419)C(MOD:00397)VVSTQT(MOD:00696,MOD:00696)ALA");
     REQUIRE(modification_sink.contain(peptide_test));
-    cout << peptide_test.get()->toString().toStdString() << " is present"
+    std::cout << peptide_test.get()->toString().toStdString() << " is present"
          << std::endl;
 
 
     peptide_test =
       PeptideStrParser::parseString("V(MOD:00552)VVMAMEEK(MOD:00429)");
     REQUIRE_FALSE(modification_sink.contain(peptide_test));
-    cout << peptide_test.get()->toString().toStdString() << " is absent"
+    std::cout << peptide_test.get()->toString().toStdString() << " is absent"
          << std::endl;
 
     peptide_test =
       PeptideStrParser::parseString("V(MOD:00552)VVMAMEEK(MOD:00552)");
     REQUIRE(modification_sink.contain(peptide_test));
-    cout << peptide_test.get()->toString().toStdString() << " is present"
+    std::cout << peptide_test.get()->toString().toStdString() << " is present"
          << std::endl;
 
 
     peptide_test = PeptideStrParser::parseString(
       "E(MOD:00429)C(MOD:00397)C(MOD:00397)VVSTQT(MOD:00696,MOD:00696)ALA");
     REQUIRE(modification_sink.contain(peptide_test));
-    cout << peptide_test.get()->toString().toStdString() << " is present"
+    std::cout << peptide_test.get()->toString().toStdString() << " is present"
          << std::endl;
 
-    cout << std::endl << "..:: test modification motifs ::.." << std::endl;
+    std::cout << std::endl << "..:: test modification motifs ::.." << std::endl;
 
     ProteinSp prot_test_motif =
       Protein("prot_test_motif", "MVVVVVMAMEEWVTFISLLLLFTVHECCVVSTQTALA")
@@ -420,12 +427,12 @@ TEST_CASE("Test Protein", "[Protein]")
       "MAMEEWVTFISLLLLFTVHECCVV(MOD:00397)STQTALA");
     REQUIRE(modification_sink.contain(peptide_test));
     REQUIRE(modification_sink.size() == 1);
-    cout << peptide_test.get()->toString().toStdString() << " is present"
+    std::cout << peptide_test.get()->toString().toStdString() << " is present"
          << std::endl;
 
 
     qDebug() << "init test protein";
-    cout << std::endl
+    std::cout << std::endl
          << "..:: Test Protein with B and Z wildcard ::.." << std::endl;
 
     // BSA
@@ -458,9 +465,9 @@ TEST_CASE("Test Protein", "[Protein]")
     REQUIRE_FALSE(digestion_bz.contain("MAXXK"));
     REQUIRE(digestion_bz.contain("MAAAK"));
     REQUIRE(digestion_bz.contain("SNEIAHR"));
-    cout << std::endl << " SNEIAHRFK FOUND " << std::endl;
+    std::cout << std::endl << " SNEIAHRFK FOUND " << std::endl;
     REQUIRE(digestion_bz.contain("SDEIAHR"));
-    cout << std::endl << " SDEIAHRFK FOUND " << std::endl;
+    std::cout << std::endl << " SDEIAHRFK FOUND " << std::endl;
   }
 
 
@@ -536,7 +543,7 @@ TEST_CASE("Test Protein code", "[proteincode]")
 
     REQUIRE(match.front().first == 2);
     REQUIRE(match.front().second == 0);
-    
+
     REQUIRE(match.back().first == 2);
     REQUIRE(match.back().second == 7);
   }
