@@ -31,7 +31,14 @@
 // ./tests/catch2-only-tests [psmfeature] -s
 
 #include <algorithm>
+
+#ifdef CATCH2_MAJOR_VERSION_2
 #include <catch2/catch.hpp>
+#elif CATCH2_MAJOR_VERSION_3
+#include <catch2/catch_all.hpp>
+using namespace Catch;
+#endif
+
 #include <pappsomspp/mzrange.h>
 #include <pappsomspp/psm/peptidespectrummatch.h>
 #include <pappsomspp/psm/features/psmfeatures.h>
@@ -56,7 +63,7 @@ TEST_CASE("psm test suite.", "[psm]")
 
   SECTION("..:: readMgf ::..", "[psm]")
   {
-    cout << std::endl << "..:: readMgf ::.." << std::endl;
+    std::cout << std::endl << "..:: readMgf ::.." << std::endl;
     // bool refine_spectrum_synthesis = false;
 
     MassSpectrum spectrum_simple =
@@ -74,7 +81,7 @@ TEST_CASE("psm test suite.", "[psm]")
     std::list<PeptideIon> ion_list;
     ion_list.push_back(PeptideIon::y);
     ion_list.push_back(PeptideIon::b);
-    cout << "spectrum_simple size  " << spectrum_simple.size() << std::endl;
+    std::cout << "spectrum_simple size  " << spectrum_simple.size() << std::endl;
     REQUIRE(spectrum_simple.size() == 100);
 
     PeptideSpectrumMatch psm(
@@ -208,7 +215,7 @@ TEST_CASE("psm features test suite.", "[psmfeature]")
 
   SECTION("..:: readMgf ::..", "[psmfeature]")
   {
-    cout << std::endl << "..:: readMgf ::.." << std::endl;
+    std::cout << std::endl << "..:: readMgf ::.." << std::endl;
     // bool refine_spectrum_synthesis = false;
 
     MassSpectrum spectrum_simple =
