@@ -28,7 +28,14 @@
 
 // ./tests/catch2-only-tests [scan15968] -s
 
+
+#ifdef CATCH2_MAJOR_VERSION_2
 #include <catch2/catch.hpp>
+#elif CATCH2_MAJOR_VERSION_3
+#include <catch2/catch_all.hpp>
+using namespace Catch;
+#endif
+
 #include <pappsomspp/mzrange.h>
 #include <pappsomspp/peptide/peptidenaturalisotopelist.h>
 #include <pappsomspp/peptide/peptidefragmentionlistbase.h>
@@ -59,7 +66,7 @@ TEST_CASE("scan 15968 test suite.", "[scan15968]")
 
   SECTION("..:: Test scan 15968 ::..", "[scan15968]")
   {
-    cout << std::endl << "..:: Test scan 15968 ::.." << std::endl;
+    std::cout << std::endl << "..:: Test scan 15968 ::.." << std::endl;
     PrecisionPtr precision = PrecisionFactory::getDaltonInstance(0.02);
     std::list<PeptideIon> ion_list;
     ion_list.push_back(PeptideIon::y);
@@ -686,9 +693,9 @@ TEST_CASE("scan 15968 test suite.", "[scan15968]")
 
     MassSpectrum spectrum_clean_isotopes(spectrum_neutral.massSpectrumFilter(
       pappso::FilterTandemDeisotope(1.5, 200)));
-    cout << spectrum_neutral.size() << std::endl;
-    cout << sclean_isotopes.size() << std::endl;
-    cout << spectrum_clean_isotopes.size() << std::endl;
+    std::cout << spectrum_neutral.size() << std::endl;
+    std::cout << sclean_isotopes.size() << std::endl;
+    std::cout << spectrum_clean_isotopes.size() << std::endl;
     REQUIRE(spectrum_clean_isotopes.equals(sclean_isotopes, precision));
 
     MassSpectrum spectrum_most_intense(spectrum_clean_isotopes);
@@ -705,9 +712,9 @@ TEST_CASE("scan 15968 test suite.", "[scan15968]")
                                       precision,
                                       ion_list,
                                       refine_spectrum_synthesis);
-    cout << "peptide " << pep15968.getSequence().toStdString()
+    std::cout << "peptide " << pep15968.getSequence().toStdString()
          << " hyperscore15968=" << hyperscore15968.getHyperscore() << std::endl;
-    cout << "peptide " << pep15968.getSequence().toStdString()
+    std::cout << "peptide " << pep15968.getSequence().toStdString()
          << " mz1=" << pep15968.getMz(1) << " mz2=" << pep15968.getMz(2)
          << std::endl;
 
