@@ -31,7 +31,14 @@
 
 // ./tests/catch2-only-tests [timsframe] -s -a
 
+
+#ifdef CATCH2_MAJOR_VERSION_2
 #include <catch2/catch.hpp>
+#elif CATCH2_MAJOR_VERSION_3
+#include <catch2/catch_all.hpp>
+using namespace Catch;
+#endif
+
 #include <QDebug>
 #include <QString>
 #include <iostream>
@@ -78,7 +85,7 @@ TEST_CASE("Test Cardano's cubic solver", "[cubicsolver]")
     REQUIRE(res.type == CardanoResultCase::positived);
     // https://www.wolframalpha.com/widgets/view.jsp?id=578d50248844454e46e24e9ed230843d
 
-    REQUIRE(res.x1.real() == Approx(-0.32588));
+    REQUIRE(res.x1 == Approx(-0.32588));
   }
 
 
@@ -100,7 +107,7 @@ TEST_CASE("Test Cardano's cubic solver", "[cubicsolver]")
     REQUIRE(res.type == CardanoResultCase::quadratic);
     // https://www.wolframalpha.com/widgets/view.jsp?id=578d50248844454e46e24e9ed230843d
 
-    REQUIRE(res.x1.real() == Approx(-0.3271626093));
+    REQUIRE(res.x1 == Approx(-0.3271626093));
   }
 
 
@@ -122,7 +129,7 @@ TEST_CASE("Test Cardano's cubic solver", "[cubicsolver]")
     REQUIRE(res.type == CardanoResultCase::line);
     // https://www.wolframalpha.com/widgets/view.jsp?id=578d50248844454e46e24e9ed230843d
 
-    REQUIRE(res.x1.real() == Approx(-0.3214285714));
+    REQUIRE(res.x1 == Approx(-0.3214285714));
   }
 }
 
@@ -203,12 +210,12 @@ TEST_CASE("Test tims frames", "[timsframe]")
     std::size_t scan_num = frame.getScanNumFromOneOverK0(one_over_k0);
 
     REQUIRE(scan_num == 400);
-    cout << std::endl << "..:: Test 1 OK ::.." << std::endl;
+    std::cout << std::endl << "..:: Test 1 OK ::.." << std::endl;
   }
 
   SECTION("Test 2")
   {
-    cout << std::endl
+    std::cout << std::endl
          << "..:: second test, new calibration parameters ::.." << std::endl;
 
 
@@ -284,7 +291,7 @@ TEST_CASE("Test tims frames", "[timsframe]")
 
 
     REQUIRE_FALSE(mz < 50.0);
-    cout << std::endl << "..:: Test 2 OK ::.." << std::endl;
+    std::cout << std::endl << "..:: Test 2 OK ::.." << std::endl;
   }
 
 
@@ -294,18 +301,17 @@ TEST_CASE("Test tims frames", "[timsframe]")
     INFO("Test case ERROR reading TIMS frame 58581");
 
     pappso::MsFileAccessor accessor(
-      "/gorgone/pappso/fichiers_fabricants/Bruker/tims_doc/tdf-sdk/"
-      "example_data/200ngHeLaPASEF_2min_compressed.d/"
-      "analysis.tdf",
+      "/gorgone/pappso/versions_logiciels_pappso/bruker/"
+      "200ngHeLaPASEF_2min_compressed.d",
       "a1");
 
 
-    accessor.setPreferedFileReaderType(pappso::MzFormat::brukerTims,
+    accessor.setPreferredFileReaderType(pappso::MzFormat::brukerTims,
                                        pappso::FileReaderType::tims_ms2);
 
 
     pappso::MsRunReaderSPtr p_msreader =
-      accessor.msRunReaderSp(accessor.getMsRunIds().front());
+      accessor.msRunReaderSPtr(accessor.getMsRunIds().front());
 
     REQUIRE(p_msreader != nullptr);
 
@@ -373,12 +379,12 @@ TEST_CASE("Test tims frames", "[timsframe]")
        "a1");
     */
 
-    accessor.setPreferedFileReaderType(pappso::MzFormat::brukerTims,
+    accessor.setPreferredFileReaderType(pappso::MzFormat::brukerTims,
                                        pappso::FileReaderType::tims);
 
 
     pappso::MsRunReaderSPtr p_msreader_tims_ms1 =
-      accessor.msRunReaderSp(accessor.getMsRunIds().front());
+      accessor.msRunReaderSPtr(accessor.getMsRunIds().front());
 
     pappso::TimsMsRunReader *tims1_reader =
       dynamic_cast<pappso::TimsMsRunReader *>(p_msreader_tims_ms1.get());
@@ -413,12 +419,12 @@ TEST_CASE("Test tims frames", "[timsframe]")
     REQUIRE_NOTHROW(p_msreader_tims_ms1.get()->massSpectrumCstSPtr(899));
 
 
-    accessor.setPreferedFileReaderType(pappso::MzFormat::brukerTims,
+    accessor.setPreferredFileReaderType(pappso::MzFormat::brukerTims,
                                        pappso::FileReaderType::tims_ms2);
 
 
     pappso::MsRunReaderSPtr p_msreader =
-      accessor.msRunReaderSp(accessor.getMsRunIds().front());
+      accessor.msRunReaderSPtr(accessor.getMsRunIds().front());
 
     REQUIRE(p_msreader != nullptr);
 
@@ -449,7 +455,7 @@ TEST_CASE("Test tims frames", "[timsframe]")
 
     INFO("Test case pappso::FileReaderType::tims start");
 
-    accessor.setPreferedFileReaderType(pappso::MzFormat::brukerTims,
+    accessor.setPreferredFileReaderType(pappso::MzFormat::brukerTims,
                                        pappso::FileReaderType::tims);
 
 
@@ -521,7 +527,7 @@ TEST_CASE("Test tims frames", "[timsframe]")
     // => avoiding sql query is not really efficient
   }
   /*
-cout << std::endl
+std::cout << std::endl
   << mass_spectrum.getMassSpectrumCstSPtr()
        .get()
        ->toString()
@@ -574,7 +580,7 @@ polynome :
 
 #elif USEPAPPSOTREE == 1
 
-  cout << std::endl
+  std::cout << std::endl
        << "..:: NO test TIMS TIC chromatogram extraction ::.." << std::endl;
 
 #endif
