@@ -29,8 +29,15 @@
 // ./tests/catch2-only-tests [filters] -s
 // ./tests/catch2-only-tests [filterpeakdelta] -s
 
-//#define CATCH_CONFIG_MAIN
+// #define CATCH_CONFIG_MAIN
+
+#ifdef CATCH2_MAJOR_VERSION_2
 #include <catch2/catch.hpp>
+#elif CATCH2_MAJOR_VERSION_3
+#include <catch2/catch_all.hpp>
+using namespace Catch;
+#endif
+
 #include <QDebug>
 #include <QString>
 #include <iostream>
@@ -411,7 +418,7 @@ TEST_CASE("trace filters test suite.", "[filters]")
       readMgf(QString(CMAKE_SOURCE_DIR)
                 .append("/tests/data/peaklist_15046_simple_xt.mgf"));
     //.applyCutOff(150).takeNmostIntense(100).applyDynamicRange(100);
-    cout << std::endl << "..:: FilterGreatestY ::.." << std::endl;
+    std::cout << std::endl << "..:: FilterGreatestY ::.." << std::endl;
 
     qDebug();
     MassSpectrum most_intense(spectrum_simple);
@@ -437,7 +444,7 @@ TEST_CASE("trace filters test suite.", "[filters]")
     REQUIRE(most_intense.size() == 100);
     qDebug();
     // 3.018830
-    cout << std::endl << "..:: resample filters ::.." << std::endl;
+    std::cout << std::endl << "..:: resample filters ::.." << std::endl;
     Trace deca_suite({DataPoint(0, 1),
                       DataPoint(1, 2),
                       DataPoint(2, 3),
@@ -494,7 +501,7 @@ TEST_CASE("trace filters test suite.", "[filters]")
     deca = deca_suite;
     deca.filter(FilterResampleKeepGreater(9));
     REQUIRE(deca == deca_greater);
-    cout << std::endl << "..:: morpho filters ::.." << std::endl;
+    std::cout << std::endl << "..:: morpho filters ::.." << std::endl;
 
     deca = deca_suite;
     deca.filter(FilterMorphoMedian(1));
@@ -512,10 +519,10 @@ TEST_CASE("trace filters test suite.", "[filters]")
                        DataPoint(11, 5),
                        DataPoint(12, 6)});
     REQUIRE(deca.size() == deca_median.size());
-    cout << "deca.size() == deca_median.size() " << deca.size() << std::endl;
+    std::cout << "deca.size() == deca_median.size() " << deca.size() << std::endl;
     REQUIRE(deca == deca_median);
 
-    cout << std::endl << "..:: FilterTandemDeisotope ::.." << std::endl;
+    std::cout << std::endl << "..:: FilterTandemDeisotope ::.." << std::endl;
     qDebug();
     MassSpectrum remove_tandem_deisotope =
       MassSpectrum(spectrum_simple)
@@ -527,6 +534,8 @@ TEST_CASE("trace filters test suite.", "[filters]")
 
     QualifiedMassSpectrum spectrum_scan_15968 = readQualifiedMassSpectrumMgf(
       QString(CMAKE_SOURCE_DIR).append("/tests/data/scan_15968.mgf"));
+    REQUIRE(spectrum_scan_15968.getPrecursorMz() == Approx(638.3693473259));
+    REQUIRE(spectrum_scan_15968.getPrecursorMass() == Approx(1274.724141718));
     qDebug();
     QualifiedMassSpectrum spectrum_removed_tandem_deisotope =
       QualifiedMassSpectrum(spectrum_scan_15968).cloneMassSpectrumSPtr();
@@ -552,7 +561,7 @@ TEST_CASE("trace filters test suite.", "[filters]")
     ion_list.push_back(PeptideIon::b);
     qDebug();
 
-    cout << std::endl << "..:: FilterRemoveC13 ::.." << std::endl;
+    std::cout << std::endl << "..:: FilterRemoveC13 ::.." << std::endl;
     qDebug();
     MassSpectrum remove_c13 =
       MassSpectrum(spectrum_simple)
@@ -584,9 +593,9 @@ TEST_CASE("trace filters test suite.", "[filters]")
       PrecisionFactory::getDaltonInstance(0.02),
       ion_list,
       true);
-    cout << "peptide " << pep15968.getSequence().toStdString()
+    std::cout << "peptide " << pep15968.getSequence().toStdString()
          << " hyperscore15968=" << hyperscore15968.getHyperscore() << std::endl;
-    cout << "peptide " << pep15968.getSequence().toStdString()
+    std::cout << "peptide " << pep15968.getSequence().toStdString()
          << " mz1=" << pep15968.getMz(1) << " mz2=" << pep15968.getMz(2)
          << std::endl;
 
@@ -600,15 +609,15 @@ TEST_CASE("trace filters test suite.", "[filters]")
       PrecisionFactory::getDaltonInstance(0.02),
       ion_list,
       true);
-    cout << "peptide " << pep15968.getSequence().toStdString()
+    std::cout << "peptide " << pep15968.getSequence().toStdString()
          << " hyperscore15968_remove_c13="
          << hyperscore15968_remove_c13.getHyperscore() << std::endl;
-    cout << "peptide " << pep15968.getSequence().toStdString()
+    std::cout << "peptide " << pep15968.getSequence().toStdString()
          << " mz1=" << pep15968.getMz(1) << " mz2=" << pep15968.getMz(2)
          << std::endl;
 
 
-    cout << std::endl
+    std::cout << std::endl
          << "..:: FilterMassSpectrumComplementIonEnhancer ::.." << std::endl;
     qDebug();
 
@@ -635,16 +644,16 @@ TEST_CASE("trace filters test suite.", "[filters]")
       PrecisionFactory::getDaltonInstance(0.02),
       ion_list,
       true);
-    cout << "peptide " << pep15968.getSequence().toStdString()
+    std::cout << "peptide " << pep15968.getSequence().toStdString()
          << " hyperscore15968_complement_ion_enhancer="
          << hyperscore15968_complement_ion_enhancer.getHyperscore()
          << std::endl;
-    cout << "peptide " << pep15968.getSequence().toStdString()
+    std::cout << "peptide " << pep15968.getSequence().toStdString()
          << " mz1=" << pep15968.getMz(1) << " mz2=" << pep15968.getMz(2)
          << std::endl;
 
 
-    cout << std::endl << "..:: FilterGreatestYperWindow ::.." << std::endl;
+    std::cout << std::endl << "..:: FilterGreatestYperWindow ::.." << std::endl;
     FilterGreatestYperWindow filter_per_window(40, 2);
     qDebug();
     QualifiedMassSpectrum spectrum_greatest_y_per_window =
@@ -664,7 +673,7 @@ TEST_CASE("trace filters test suite.", "[filters]")
     qDebug();
 
 
-    cout << std::endl
+    std::cout << std::endl
          << "..:: FilterGreatestYperWindow  on scan_PXD001468.mgf ::.."
          << std::endl;
     QualifiedMassSpectrum spectrum_scan_PXD001468 =
@@ -703,27 +712,27 @@ TEST_CASE("trace filters test suite.", "[filters]")
         PrecisionFactory::getDaltonInstance(0.02),
         ion_list,
         true);
-      cout << "peptide " << pep15968.getSequence().toStdString()
+      std::cout << "peptide " << pep15968.getSequence().toStdString()
            << " hyperscore15968_greatest_y_per_window="
            << hyperscore15968_greatest_y_per_window.getHyperscore() <<
-      std::endl; cout << "peptide " << pep15968.getSequence().toStdString()
+      std::endl; std::cout << "peptide " << pep15968.getSequence().toStdString()
            << " mz1=" << pep15968.getMz(1) << " mz2=" << pep15968.getMz(2) <<
       endl;
 
     */
 
-    cout << std::endl << "..:: FilterSuiteString ::.." << std::endl;
+    std::cout << std::endl << "..:: FilterSuiteString ::.." << std::endl;
 
     std::shared_ptr<pappso::FilterSuiteString> filter_suite_str =
       std::make_shared<pappso::FilterSuiteString>(
         "chargeDeconvolution|0.02dalton");
 
 
-    cout << std::endl
+    std::cout << std::endl
          << "filter_suite_str = "
          << filter_suite_str.get()->toString().toStdString() << std::endl;
 
-    cout << std::endl
+    std::cout << std::endl
          << "..:: FilterChargeDeconvolution from FilterSuiteString ::.."
          << std::endl;
 
@@ -754,35 +763,35 @@ TEST_CASE("trace filters test suite.", "[filters]")
                            DataPoint(24, 220),
                            // Third
                            DataPoint(62 - MHPLUS, 35)});
-    cout << "Transform Trace data" << std::endl;
+    std::cout << "Transform Trace data" << std::endl;
     filter_charge_deconvolution->filter(loaded_trace);
 
 
     if(loaded_trace != theorical_trace)
       {
-        cerr << "transformed Trace are different from theorical trace :"
+        std::cerr << "transformed Trace are different from theorical trace :"
              << std::endl;
 
         if(loaded_trace.xValues().size() == theorical_trace.xValues().size())
           {
-            cerr << "transformed trace: \t";
+            std::cerr << "transformed trace: \t";
             for(std::size_t i = 0; i < loaded_trace.xValues().size(); i++)
               {
-                cerr << "(" << loaded_trace.xValues()[i] << ", "
+                std::cerr << "(" << loaded_trace.xValues()[i] << ", "
                      << loaded_trace.yValues()[i] << ") ";
               }
-            cerr << std::endl;
-            cerr << "theorical trace : \t";
+            std::cerr << std::endl;
+            std::cerr << "theorical trace : \t";
             for(std::size_t i = 0; i < theorical_trace.xValues().size(); i++)
               {
-                cerr << "(" << theorical_trace.xValues()[i] << ", "
+                std::cerr << "(" << theorical_trace.xValues()[i] << ", "
                      << theorical_trace.yValues()[i] << ") ";
               }
-            cerr << std::endl;
+            std::cerr << std::endl;
           }
         else
           {
-            cerr << "Number of peaks is different : "
+            std::cerr << "Number of peaks is different : "
                  << loaded_trace.xValues().size() << " vs "
                  << theorical_trace.xValues().size();
           }
@@ -811,7 +820,7 @@ TEST_CASE("trace filters test suite.", "[filters]")
 
     REQUIRE(anti_spike_trace[9].y == 0);
     REQUIRE(anti_spike_trace[2].y == 3);
-    // cout << std::endl << anti_spike_trace.toString().toStdString() <<
+    // std::cout << std::endl << anti_spike_trace.toString().toStdString() <<
     // std::endl;
 
     INFO("filter_anti_spike_too_big");
