@@ -30,7 +30,13 @@
 // ./tests/catch2-only-tests [uimonitor] -s
 
 
+#ifdef CATCH2_MAJOR_VERSION_2
 #include <catch2/catch.hpp>
+#elif CATCH2_MAJOR_VERSION_3
+#include <catch2/catch_all.hpp>
+using namespace Catch;
+#endif
+
 #include <QDebug>
 #include <QIODevice>
 #include <pappsomspp/processing/uimonitor/uimonitortextpercent.h>
