@@ -26,9 +26,15 @@
  *implementation
  ******************************************************************************/
 
+// ./tests/catch2-only-tests [xtandemspectrum] -s
 
-#define CATCH_CONFIG_MAIN
+#ifdef CATCH2_MAJOR_VERSION_2
 #include <catch2/catch.hpp>
+#elif CATCH2_MAJOR_VERSION_3
+#include <catch2/catch_all.hpp>
+using namespace Catch;
+#endif
+
 #include <pappsomspp/mzrange.h>
 #include <pappsomspp/peptide/peptidenaturalisotopelist.h>
 #include <pappsomspp/peptide/peptidefragmentionlistbase.h>
@@ -56,13 +62,14 @@ TEST_CASE("Xtandem spectrum test suite.", "[xtandemspectrum]")
 
   SECTION("..:: readMgf ::..", "[xtandemspectrum]")
   {
-    cout << std::endl
-         << "..:: readMgf ::.." << QDir::currentPath().toStdString() << std::endl;
+    std::cout << std::endl
+              << "..:: readMgf ::.." << QDir::currentPath().toStdString()
+              << std::endl;
 
     MassSpectrum spectrum = readMgf(
       QString(CMAKE_SOURCE_DIR).append("/tests/data/peaklist_15046.mgf"));
 
-    cout << spectrum.toString().toStdString() << std::endl;
+    std::cout << spectrum.toString().toStdString() << std::endl;
     MassSpectrum spectrum_orig(spectrum);
     REQUIRE(spectrum.equals(spectrum_orig,
                             PrecisionFactory::getDaltonInstance(0.00002)));
@@ -79,10 +86,19 @@ TEST_CASE("Xtandem spectrum test suite.", "[xtandemspectrum]")
       readMgf(QString(CMAKE_SOURCE_DIR)
                 .append("/tests/data/peaklist_15046_simple_xt.mgf"))
         .massSpectrumFilter(MassSpectrumFilterGreatestItensities(7));
+
     REQUIRE_FALSE(spectrum == spectrum_simple);
+    std::vector<double> expected_mass_list(
+      {157.133, 175.119, 185.128, 308.188, 401.287, 886.535, 1072.6});
+    REQUIRE_THAT(spectrum_simple.xValues(),
+                 Catch::Approx(expected_mass_list).margin(0.00001));
+    std::vector<double> expected_intensity_list(
+      {100.0, 30.0, 42.0, 33.0, 27.0, 19.0, 21.0});
+    REQUIRE_THAT(spectrum_simple.yValues(),
+                 Catch::Approx(expected_intensity_list).margin(0.00001));
     // mh="1256.7213" z=2 AIADGSLLDLLR
     Peptide peptide("AIADGSLLDLLR");
-    qDebug() << "spectrum.removeParent";
+    INFO("spectrum.removeParent");
 
     XtandemSpectrumProcess xt_spectrum_process;
     xt_spectrum_process.setExcludeParent(true);
@@ -96,7 +112,8 @@ TEST_CASE("Xtandem spectrum test suite.", "[xtandemspectrum]")
     // spectrum.removeMassRange(neutral_loss_mass).applyCutOff(150).takeNmostIntense(7).applyDynamicRange(100).round();
     spectrum = xt_spectrum_process.process(spectrum, 628.86414, 2);
     FilterRoundY().filter(spectrum);
-    qDebug() << "pepmz=" << peptide.makePeptideSp().get()->getMz(2);
+    REQUIRE(peptide.makePeptideSp().get()->getMz(2) ==
+            Catch::Detail::Approx(628.8640771426));
     spectrum.debugPrintValues();
     spectrum_simple.debugPrintValues();
     REQUIRE(spectrum.equals(spectrum_simple,
